@@ -3,118 +3,186 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="80"/>
+        <source>Using configuration file at:</source>
+        <translation>Používá se konfigurační soubor:</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Behavior</source>
         <translation>Chování</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Automatically save documents</source>
         <translation>Automaticky ukládat dokumenty</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Automatically open last documents on startup</source>
-        <translation>Automaticky otevírat dokumenty</translation>
+        <translation>Při spuštění automaticky otevřít naposledy zobrazené dokumenty</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Restore window geometry</source>
         <translation>Obnovit rozměry okna</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
-        <source>Use live preview by default</source>
-        <translation>Vždy použít živý náhled</translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Open external links in ReText window</source>
         <translation>Otevírat externí odkazy v okně ReTextu</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Markdown syntax extensions (comma-separated)</source>
         <translation>Přípony syntaxe Markdown (oddělené čárkami)</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Enable synchronized scrolling for Markdown</source>
         <translation>Zapnout synchronizovaný posun pro Markdown</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="169"/>
         <source>Editor</source>
         <translation>Editor</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Highlight current line</source>
         <translation>Zvýrazňovat aktuální řádek</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Show line numbers</source>
         <translation>Zobrazovat čísla řádků</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Line numbers are relative to current line</source>
+        <translation>Číslování řádků je odvozené od aktuálního řádku</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Tab key inserts spaces</source>
         <translation>Klávesa Tabulátor vkládá mezery</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Tabulation width</source>
         <translation>Šířka tabulátoru</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Draw vertical line at column</source>
-        <translation>Svislá čára u sloupců</translation>
+        <translation>Svislá čára v sloupci</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Enable soft wrap</source>
+        <translation>Povolit zalamování na místě bílých znaků</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Show document stats</source>
+        <translation>Zobrazovat statistiky dokumentu</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Interface</source>
         <translation>Rozhraní</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Icon theme name</source>
         <translation>Název motivu ikon</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Stylesheet file</source>
-        <translation>Soubor stylu</translation>
+        <translation>Soubor stylopisu</translation>
     </message>
     <message>
-        <location filename="config.py" line="104"/>
+        <location filename="../ReText/config.py" line="151"/>
         <source>Help</source>
         <translation>Nápověda</translation>
     </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Number of recent documents</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Default preview state</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Hide toolbar</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Hide tabs bar when there is only one tab</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Show full path in window title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="170"/>
+        <source>Live preview</source>
+        <translation>Živý náhled</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="171"/>
+        <source>Normal preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
     <message>
-        <location filename="config.py" line="34"/>
+        <location filename="../ReText/config.py" line="35"/>
         <source>(none)</source>
         <translation>(prázdý)</translation>
     </message>
     <message>
-        <location filename="config.py" line="41"/>
+        <location filename="../ReText/config.py" line="42"/>
         <source>Select file to open</source>
-        <translation>Otevřít soubor</translation>
+        <translation>Vyberte soubor, který se má otevřít</translation>
+    </message>
+</context>
+<context>
+    <name>InsertTableDialog</name>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="27"/>
+        <source>Insert table</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="36"/>
+        <source>Number of rows</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="37"/>
+        <source>Number of columns</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="dialogs.py" line="44"/>
+        <location filename="../ReText/dialogs.py" line="44"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>Zadejte název lokalizace (např.: cs_CZ)</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="50"/>
+        <location filename="../ReText/dialogs.py" line="50"/>
         <source>Set as default</source>
         <translation>Nastavit jako výchozí</translation>
     </message>
@@ -122,12 +190,12 @@
 <context>
     <name>Proxy</name>
     <message>
-        <location filename="fakevimeditor.py" line="64"/>
+        <location filename="../ReText/fakevimeditor.py" line="61"/>
         <source>No write since last change (add ! to override)</source>
         <translation>Žádný zápis od poslední změny (přidejte ! pro přepsání)</translation>
     </message>
     <message>
-        <location filename="fakevimeditor.py" line="121"/>
+        <location filename="../ReText/fakevimeditor.py" line="118"/>
         <source>Information</source>
         <translation>Informace</translation>
     </message>
@@ -135,12 +203,17 @@
 <context>
     <name>ReTextEdit</name>
     <message>
-        <location filename="editor.py" line="292"/>
+        <location filename="../ReText/editor.py" line="212"/>
+        <source>Add to dictionary</source>
+        <translation>Přidat do slovníku</translation>
+    </message>
+    <message>
+        <location filename="../ReText/editor.py" line="391"/>
         <source>Save image</source>
         <translation>Uložit obrázek</translation>
     </message>
     <message>
-        <location filename="editor.py" line="292"/>
+        <location filename="../ReText/editor.py" line="391"/>
         <source>Images (*.png *.jpg)</source>
         <translation>Obrázky (*.png *.jpg)</translation>
     </message>
@@ -148,475 +221,574 @@
 <context>
     <name>ReTextTab</name>
     <message>
-        <location filename="tab.py" line="183"/>
+        <location filename="../ReText/tab.py" line="184"/>
         <source>New document</source>
         <translation>Nový dokument</translation>
     </message>
     <message>
-        <location filename="tab.py" line="188"/>
+        <location filename="../ReText/tab.py" line="189"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation>Nelze analyzovat obsah souboru, zkontrolujte, zda máte nainstalován &lt;a href=&quot;%s&quot;&gt;nezbytný modul&lt;/a&gt;!</translation>
     </message>
+    <message>
+        <location filename="../ReText/tab.py" line="478"/>
+        <source>Create missing file?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="478"/>
+        <source>The file &apos;%s&apos; does not exist.
+
+Do you want to create it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="511"/>
+        <source>File could not be created</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="511"/>
+        <source>Could not create file &apos;%s&apos;: %s</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="85"/>
+        <location filename="../ReText/window.py" line="82"/>
         <source>File toolbar</source>
         <translation>Lišta souboru</translation>
     </message>
     <message>
-        <location filename="window.py" line="87"/>
+        <location filename="../ReText/window.py" line="84"/>
         <source>Edit toolbar</source>
         <translation>Lišta úprav</translation>
     </message>
     <message>
-        <location filename="window.py" line="89"/>
+        <location filename="../ReText/window.py" line="86"/>
         <source>Search toolbar</source>
         <translation>Lišta hledání</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="../ReText/window.py" line="90"/>
         <source>New</source>
         <translation>Nový</translation>
     </message>
     <message>
-        <location filename="window.py" line="96"/>
+        <location filename="../ReText/window.py" line="93"/>
         <source>Open</source>
         <translation>Otevřít</translation>
     </message>
     <message>
-        <location filename="window.py" line="99"/>
+        <location filename="../ReText/window.py" line="96"/>
         <source>Set encoding</source>
         <translation>Nastavit kódování</translation>
     </message>
     <message>
-        <location filename="window.py" line="1096"/>
+        <location filename="../ReText/window.py" line="1190"/>
         <source>Reload</source>
         <translation>Znovu načíst</translation>
     </message>
     <message>
-        <location filename="window.py" line="105"/>
+        <location filename="../ReText/window.py" line="102"/>
         <source>Save</source>
         <translation>Uložit</translation>
     </message>
     <message>
-        <location filename="window.py" line="109"/>
+        <location filename="../ReText/window.py" line="106"/>
         <source>Save as</source>
         <translation>Uložit jako</translation>
     </message>
     <message>
-        <location filename="window.py" line="111"/>
+        <location filename="../ReText/window.py" line="108"/>
         <source>Next tab</source>
-        <translation>Následující záložka</translation>
+        <translation>Následující karta</translation>
     </message>
     <message>
-        <location filename="window.py" line="113"/>
+        <location filename="../ReText/window.py" line="110"/>
         <source>Previous tab</source>
-        <translation>Předchozí záložka</translation>
+        <translation>Předchozí karta</translation>
     </message>
     <message>
-        <location filename="window.py" line="115"/>
+        <location filename="../ReText/window.py" line="112"/>
+        <source>Close tab</source>
+        <translation>Zavřít kartu</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="114"/>
         <source>Print</source>
         <translation>Tisknout</translation>
     </message>
     <message>
-        <location filename="window.py" line="118"/>
+        <location filename="../ReText/window.py" line="117"/>
         <source>Print preview</source>
         <translation>Náhled tisku</translation>
     </message>
     <message>
-        <location filename="window.py" line="120"/>
+        <location filename="../ReText/window.py" line="119"/>
         <source>View HTML code</source>
-        <translation>Zobrazit HTML kód</translation>
+        <translation>Zobrazit kód HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="121"/>
+        <location filename="../ReText/window.py" line="120"/>
         <source>Change editor font</source>
-        <translation>Změnit font editoru</translation>
+        <translation>Změnit písmo v editoru</translation>
     </message>
     <message>
-        <location filename="window.py" line="123"/>
+        <location filename="../ReText/window.py" line="122"/>
         <source>Change preview font</source>
-        <translation>Změnit font náhledu</translation>
+        <translation>Změnit písmo v náhledu</translation>
     </message>
     <message>
-        <location filename="window.py" line="125"/>
+        <location filename="../ReText/window.py" line="124"/>
         <source>Find text</source>
         <translation>Najít text</translation>
     </message>
     <message>
-        <location filename="window.py" line="129"/>
+        <location filename="../ReText/window.py" line="129"/>
         <source>Preview</source>
         <translation>Náhled</translation>
     </message>
     <message>
-        <location filename="window.py" line="139"/>
+        <location filename="../ReText/window.py" line="139"/>
         <source>Live preview</source>
         <translation>Živý náhled</translation>
     </message>
     <message>
-        <location filename="window.py" line="144"/>
+        <location filename="../ReText/window.py" line="146"/>
         <source>Table editing mode</source>
-        <translation>Editační mód pro tablet</translation>
+        <translation>Režim úpravy tabulek</translation>
     </message>
     <message>
-        <location filename="window.py" line="148"/>
+        <location filename="../ReText/window.py" line="152"/>
         <source>FakeVim mode</source>
-        <translation>Mód FakeVim</translation>
+        <translation>Režim FakeVim</translation>
     </message>
     <message>
-        <location filename="window.py" line="153"/>
+        <location filename="../ReText/window.py" line="157"/>
         <source>Fullscreen mode</source>
-        <translation>Režim na celou obrazovku</translation>
+        <translation>Celoobrazovkový režim</translation>
     </message>
     <message>
-        <location filename="window.py" line="588"/>
+        <location filename="../ReText/window.py" line="630"/>
         <source>Preferences</source>
         <translation>Nastavení</translation>
     </message>
     <message>
-        <location filename="window.py" line="163"/>
+        <location filename="../ReText/window.py" line="168"/>
         <source>Quit</source>
         <translation>Ukončit</translation>
     </message>
     <message>
-        <location filename="window.py" line="166"/>
+        <location filename="../ReText/window.py" line="171"/>
         <source>Undo</source>
         <translation>Zpět</translation>
     </message>
     <message>
-        <location filename="window.py" line="168"/>
+        <location filename="../ReText/window.py" line="173"/>
         <source>Redo</source>
         <translation>Znovu</translation>
     </message>
     <message>
-        <location filename="window.py" line="170"/>
+        <location filename="../ReText/window.py" line="175"/>
         <source>Copy</source>
         <translation>Kopírovat</translation>
     </message>
     <message>
-        <location filename="window.py" line="172"/>
+        <location filename="../ReText/window.py" line="177"/>
         <source>Cut</source>
         <translation>Vyjmout</translation>
     </message>
     <message>
-        <location filename="window.py" line="174"/>
+        <location filename="../ReText/window.py" line="179"/>
         <source>Paste</source>
         <translation>Vložit</translation>
     </message>
     <message>
-        <location filename="window.py" line="184"/>
+        <location filename="../ReText/window.py" line="183"/>
+        <source>Move line up</source>
+        <translation>Přesunout o řádek výše</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="185"/>
+        <source>Move line down</source>
+        <translation>Přesunout o řádek níže</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="195"/>
         <source>Enable</source>
         <translation>Povolit</translation>
     </message>
     <message>
-        <location filename="window.py" line="185"/>
+        <location filename="../ReText/window.py" line="196"/>
         <source>Set locale</source>
         <translation>Nastavit lokalizaci</translation>
     </message>
     <message>
-        <location filename="window.py" line="186"/>
+        <location filename="../ReText/window.py" line="197"/>
         <source>Use WebKit renderer</source>
         <translation>Použít WebKit k vykreslování</translation>
     </message>
     <message>
-        <location filename="window.py" line="191"/>
+        <location filename="../ReText/window.py" line="202"/>
         <source>Use WebEngine (Chromium) renderer</source>
         <translation>Použít WebEngine (Chromium) k vykreslování</translation>
     </message>
     <message>
-        <location filename="window.py" line="196"/>
+        <location filename="../ReText/window.py" line="207"/>
         <source>Show directory</source>
         <translation>Zobrazit složku</translation>
     </message>
     <message>
-        <location filename="window.py" line="197"/>
+        <location filename="../ReText/window.py" line="208"/>
         <source>Next</source>
         <translation>Následující</translation>
     </message>
     <message>
-        <location filename="window.py" line="199"/>
+        <location filename="../ReText/window.py" line="210"/>
         <source>Previous</source>
         <translation>Předchozí</translation>
     </message>
     <message>
-        <location filename="window.py" line="201"/>
+        <location filename="../ReText/window.py" line="212"/>
         <source>Replace</source>
         <translation>Nahradit</translation>
     </message>
     <message>
-        <location filename="window.py" line="203"/>
+        <location filename="../ReText/window.py" line="214"/>
         <source>Replace all</source>
         <translation>Nahradit vše</translation>
     </message>
     <message>
-        <location filename="window.py" line="207"/>
+        <location filename="../ReText/window.py" line="218"/>
         <source>Close</source>
         <translation>Zavřít</translation>
     </message>
     <message>
-        <location filename="window.py" line="210"/>
+        <location filename="../ReText/window.py" line="222"/>
         <source>Get help online</source>
         <translation>Získejte nápovědu online</translation>
     </message>
     <message>
-        <location filename="window.py" line="211"/>
+        <location filename="../ReText/window.py" line="223"/>
         <source>About ReText</source>
         <translation>O programu ReText</translation>
     </message>
     <message>
-        <location filename="window.py" line="214"/>
+        <location filename="../ReText/window.py" line="226"/>
         <source>About Qt</source>
         <translation>O Qt</translation>
     </message>
     <message>
-        <location filename="window.py" line="229"/>
+        <location filename="../ReText/window.py" line="241"/>
         <source>Bold</source>
         <translation>Tučné</translation>
     </message>
     <message>
-        <location filename="window.py" line="231"/>
+        <location filename="../ReText/window.py" line="243"/>
         <source>Italic</source>
         <translation>Kurzíva</translation>
     </message>
     <message>
-        <location filename="window.py" line="233"/>
+        <location filename="../ReText/window.py" line="245"/>
         <source>Underline</source>
         <translation>Podtržené</translation>
     </message>
     <message>
-        <location filename="window.py" line="299"/>
+        <location filename="../ReText/window.py" line="318"/>
         <source>Formatting</source>
         <translation>Formátování</translation>
     </message>
     <message>
-        <location filename="window.py" line="245"/>
+        <location filename="../ReText/window.py" line="258"/>
         <source>Symbols</source>
         <translation>Symboly</translation>
     </message>
     <message>
-        <location filename="window.py" line="250"/>
+        <location filename="../ReText/window.py" line="263"/>
         <source>File</source>
         <translation>Soubor</translation>
     </message>
     <message>
-        <location filename="window.py" line="251"/>
+        <location filename="../ReText/window.py" line="264"/>
         <source>Edit</source>
         <translation>Upravit</translation>
     </message>
     <message>
-        <location filename="window.py" line="252"/>
+        <location filename="../ReText/window.py" line="265"/>
         <source>Help</source>
         <translation>Nápověda</translation>
     </message>
     <message>
-        <location filename="window.py" line="255"/>
+        <location filename="../ReText/window.py" line="268"/>
         <source>Open recent</source>
         <translation>Otevřít nedávné</translation>
     </message>
     <message>
-        <location filename="window.py" line="267"/>
+        <location filename="../ReText/window.py" line="281"/>
         <source>Export</source>
         <translation>Exportovat</translation>
     </message>
     <message>
-        <location filename="window.py" line="288"/>
+        <location filename="../ReText/window.py" line="306"/>
         <source>Spell check</source>
         <translation>Kontrola pravopisu</translation>
     </message>
     <message>
-        <location filename="window.py" line="296"/>
+        <location filename="../ReText/window.py" line="315"/>
         <source>Default markup</source>
         <translation>Výchozí syntax</translation>
     </message>
     <message>
-        <location filename="window.py" line="339"/>
+        <location filename="../ReText/window.py" line="360"/>
         <source>Search</source>
         <translation>Najít</translation>
     </message>
     <message>
-        <location filename="window.py" line="342"/>
+        <location filename="../ReText/window.py" line="363"/>
         <source>Replace with</source>
-        <translation>Nahradit s</translation>
+        <translation>Nahradit</translation>
     </message>
     <message>
-        <location filename="window.py" line="344"/>
+        <location filename="../ReText/window.py" line="365"/>
         <source>Case sensitively</source>
         <translation>Rozlišovat velikost písmen</translation>
     </message>
     <message>
-        <location filename="window.py" line="492"/>
+        <location filename="../ReText/window.py" line="526"/>
         <source>New document</source>
         <translation>Nový dokument</translation>
     </message>
     <message>
-        <location filename="window.py" line="664"/>
+        <location filename="../ReText/window.py" line="714"/>
         <source>Please, save the file somewhere.</source>
         <translation>Prosím, soubor někam uložte.</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="830"/>
         <source>Select one or several files to open</source>
         <translation>Vyberte jeden nebo více souborů k otevření</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="1248"/>
         <source>Supported files</source>
         <translation>Podporované soubory</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="1248"/>
         <source>All files (*)</source>
         <translation>Všechny soubory (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="818"/>
+        <location filename="../ReText/window.py" line="869"/>
         <source>Select file encoding from the list:</source>
         <translation>Vyberte ze seznamu kódování souboru:</translation>
     </message>
     <message>
-        <location filename="window.py" line="839"/>
+        <location filename="../ReText/window.py" line="892"/>
         <source>Plain text (*.txt)</source>
         <translation>Prostý text (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="842"/>
+        <location filename="../ReText/window.py" line="895"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>%s soubory</translation>
     </message>
     <message>
-        <location filename="window.py" line="919"/>
+        <location filename="../ReText/window.py" line="970"/>
         <source>Save file</source>
         <translation>Uložit soubor</translation>
     </message>
     <message>
-        <location filename="window.py" line="860"/>
+        <location filename="../ReText/window.py" line="915"/>
         <source>Cannot save to file which is open in another tab!</source>
         <translation>Nelze uložit do souboru, který je otevřený v jiné záložce!</translation>
     </message>
     <message>
-        <location filename="window.py" line="884"/>
+        <location filename="../ReText/window.py" line="938"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Nelze uložit, protože soubor je pouze pro čtení!</translation>
     </message>
     <message>
-        <location filename="window.py" line="909"/>
+        <location filename="../ReText/window.py" line="960"/>
         <source>Export document to ODT</source>
         <translation>Exportovat dokument do ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="909"/>
+        <location filename="../ReText/window.py" line="960"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Textové soubory OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="919"/>
+        <location filename="../ReText/window.py" line="970"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Soubory HTML (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="940"/>
+        <location filename="../ReText/window.py" line="993"/>
+        <source>Unrecognized paperSize setting &quot;%s&quot;.</source>
+        <translation>Nerozpoznané nastavení paperSize &quot;%s&quot;.</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="1019"/>
         <source>Export document to PDF</source>
         <translation>Exportovat dokument do PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="940"/>
+        <location filename="../ReText/window.py" line="1019"/>
         <source>PDF files (*.pdf)</source>
         <translation>Soubory PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="960"/>
+        <location filename="../ReText/window.py" line="1046"/>
         <source>Print document</source>
         <translation>Tisknout dokument</translation>
     </message>
     <message>
-        <location filename="window.py" line="984"/>
+        <location filename="../ReText/window.py" line="1069"/>
         <source>Export document</source>
         <translation>Exportovat dokument</translation>
     </message>
     <message>
-        <location filename="window.py" line="1005"/>
+        <location filename="../ReText/window.py" line="1090"/>
         <source>Failed to execute the command:</source>
         <translation>Nepodařilo se spustit příkaz:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1039"/>
+        <location filename="../ReText/window.py" line="1131"/>
         <source>Alt text</source>
         <translation>Alternativní text</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="../ReText/window.py" line="1132"/>
         <source>URL</source>
         <translation>URL</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="../ReText/window.py" line="1132"/>
         <source>Link text</source>
-        <translation>Odkaz</translation>
+        <translation>Text odkazu</translation>
     </message>
     <message>
-        <location filename="window.py" line="1080"/>
+        <location filename="../ReText/window.py" line="1173"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
         <translation>Soubor byl smazán jinou aplikací.
-Před zavřením programu se ujistěte, že jste soubor uložili.</translation>
+Před zavřením programu se prosím ujistěte, že jste soubor uložili.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1087"/>
+        <location filename="../ReText/window.py" line="1181"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
-        <translation>Soubor byl změněn. Chcete načíst novou verzi?
-(Tímto se zruší všechny změny)
+        <translation>Tento dokument byl změněn jinou aplikací.
+Chcete načíst novou verzi? (Tímto se zruší všechny změny.)
 </translation>
     </message>
     <message>
-        <location filename="window.py" line="1092"/>
+        <location filename="../ReText/window.py" line="1186"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
-        <translation>Pokud se rozhodnete soubor nenačíst, automatické ukádání bude vypnuto, aby se zabránilo ztrátě dat.</translation>
+        <translation>Pokud se rozhodnete, že soubor nechcete znovu načíst, automatické ukládání bude v tomto sezení vypnuto, aby se zabránilo ztrátě dat.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1116"/>
+        <location filename="../ReText/window.py" line="1210"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Dokument byl změněn. Chcete uložit své změny?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1145"/>
+        <location filename="../ReText/window.py" line="1238"/>
         <source>HTML code</source>
-        <translation>HTML kód</translation>
+        <translation>Kód HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>ReText %s (using PyMarkups %s)</source>
         <translation>ReText %s (s použitím PyMarkups %s)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Jednoduchý, ale mocný editor pro Markdown a reStructuredText</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Autor: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Website</source>
         <translation>Webové stránky</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Markdown syntax</source>
         <translation>Syntax Markdown</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>reStructuredText syntax</source>
-        <translation>reStructuredText syntaxe</translation>
+        <translation>Syntax reStructuredText</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="678"/>
+        <source>Go to line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="144"/>
+        <source>Insert table</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="181"/>
+        <source>Paste image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="678"/>
+        <source>Type the line number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="149"/>
+        <source>Insert images by file path</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="1248"/>
+        <source>Select one or several images to open</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>TextInfoArea</name>
+    <message>
+        <location filename="../ReText/editor.py" line="582"/>
+        <source>%d w | %d a | %d c</source>
+        <comment>count of words, alphanumeric characters, all characters</comment>
+        <translation>%d slov | %d písmen/číslic | %d znaků</translation>
+    </message>
+</context>
+<context>
+    <name>main</name>
+    <message>
+        <location filename="../ReText/__main__.py" line="77"/>
+        <source>Open the files in preview mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/__main__.py" line="79"/>
+        <source>Create a new window even if there is an existing one</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/__main__.py" line="83"/>
+        <source>List of files to open</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
