@@ -3,118 +3,186 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Behavior</source>
         <translation>Comportement</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Automatically save documents</source>
         <translation>Sauvegarde automatique des documents</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
-        <source>Automatically open last documents on startup</source>
-        <translation>Ouvrir automatiquement les derniers documents au démarrage</translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Restore window geometry</source>
         <translation>Restaurer la taille de la fenêtre</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
-        <source>Use live preview by default</source>
-        <translation>Utiliser l&apos;aperçu dynamique par défaut</translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Open external links in ReText window</source>
         <translation>Ouvrir les liens externes dans la fenêtre de ReText</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Markdown syntax extensions (comma-separated)</source>
         <translation>Extensions Markdown (séparées par une virgule)</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
-        <source>Enable synchronized scrolling for Markdown</source>
-        <translation>Activer le défilement synchronisé pour Markdown</translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="169"/>
         <source>Editor</source>
         <translation>Éditeur</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Highlight current line</source>
         <translation>Surligner la ligne courante</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Show line numbers</source>
         <translation>Afficher les numéros de ligne</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Tab key inserts spaces</source>
         <translation>La touche Tab insère des espaces</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Tabulation width</source>
         <translation>Largeur de tabulation</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
-        <source>Draw vertical line at column</source>
-        <translation>Dessiner une ligne verticale sur la colonne</translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Interface</source>
         <translation>Interface</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Icon theme name</source>
         <translation>Nom du thème d’icônes</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Stylesheet file</source>
         <translation>Fichier de feuille de style</translation>
     </message>
     <message>
-        <location filename="config.py" line="104"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Show document stats</source>
+        <translation>Afficher les statistiques du document</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="151"/>
         <source>Help</source>
         <translation>Aide</translation>
     </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Enable synchronized scrolling for Markdown</source>
+        <translation>Activer le défilement synchronisé pour Markdown</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Draw vertical line at column</source>
+        <translation>Dessiner une ligne verticale sur la colonne</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Automatically open last documents on startup</source>
+        <translation>Ouvrir automatiquement les derniers documents au démarrage</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="80"/>
+        <source>Using configuration file at:</source>
+        <translation type="unfinished">Fichier de configuration situé à :</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Number of recent documents</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Default preview state</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Line numbers are relative to current line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Enable soft wrap</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Hide toolbar</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Hide tabs bar when there is only one tab</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Show full path in window title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="170"/>
+        <source>Live preview</source>
+        <translation type="unfinished">Aperçu dynamique</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="171"/>
+        <source>Normal preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
     <message>
-        <location filename="config.py" line="34"/>
+        <location filename="../ReText/config.py" line="35"/>
         <source>(none)</source>
         <translation>(aucun)</translation>
     </message>
     <message>
-        <location filename="config.py" line="41"/>
+        <location filename="../ReText/config.py" line="42"/>
         <source>Select file to open</source>
         <translation>Choisir le fichier à ouvrir</translation>
     </message>
 </context>
+<context>
+    <name>InsertTableDialog</name>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="27"/>
+        <source>Insert table</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="36"/>
+        <source>Number of rows</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="37"/>
+        <source>Number of columns</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="dialogs.py" line="44"/>
+        <location filename="../ReText/dialogs.py" line="44"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>Entrez le préfixe pour la langue (exemple: fr_FR)</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="50"/>
+        <location filename="../ReText/dialogs.py" line="50"/>
         <source>Set as default</source>
         <translation>Définir par défaut</translation>
     </message>
@@ -122,12 +190,12 @@
 <context>
     <name>Proxy</name>
     <message>
-        <location filename="fakevimeditor.py" line="64"/>
+        <location filename="../ReText/fakevimeditor.py" line="61"/>
         <source>No write since last change (add ! to override)</source>
         <translation>Pas d&apos;écriture depuis le dernier changement (ajoutez ! pour écraser)</translation>
     </message>
     <message>
-        <location filename="fakevimeditor.py" line="121"/>
+        <location filename="../ReText/fakevimeditor.py" line="118"/>
         <source>Information</source>
         <translation>Information</translation>
     </message>
@@ -135,436 +203,423 @@
 <context>
     <name>ReTextEdit</name>
     <message>
-        <location filename="editor.py" line="292"/>
+        <location filename="../ReText/editor.py" line="391"/>
         <source>Save image</source>
         <translation>Enregistrer l&apos;image</translation>
     </message>
     <message>
-        <location filename="editor.py" line="292"/>
+        <location filename="../ReText/editor.py" line="391"/>
         <source>Images (*.png *.jpg)</source>
         <translation>Images (*.png *.jpg)</translation>
     </message>
+    <message>
+        <location filename="../ReText/editor.py" line="212"/>
+        <source>Add to dictionary</source>
+        <translation>Ajouter au dictionaire</translation>
+    </message>
 </context>
 <context>
     <name>ReTextTab</name>
     <message>
-        <location filename="tab.py" line="183"/>
+        <location filename="../ReText/tab.py" line="184"/>
         <source>New document</source>
         <translation>Nouveau document</translation>
     </message>
     <message>
-        <location filename="tab.py" line="188"/>
+        <location filename="../ReText/tab.py" line="189"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation>Impossible d&apos;analyser le contenu du fichier, vérifier si les &lt;a href=&quot;%s&quot;&gt;modules nécessaires&lt;/a&gt; sont installés!</translation>
     </message>
+    <message>
+        <location filename="../ReText/tab.py" line="478"/>
+        <source>Create missing file?</source>
+        <translation>Créer le document manquant ?</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="478"/>
+        <source>The file &apos;%s&apos; does not exist.
+
+Do you want to create it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="511"/>
+        <source>File could not be created</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="511"/>
+        <source>Could not create file &apos;%s&apos;: %s</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="85"/>
+        <location filename="../ReText/window.py" line="82"/>
         <source>File toolbar</source>
         <translation>Barre d&apos;outil Fichier</translation>
     </message>
     <message>
-        <location filename="window.py" line="87"/>
+        <location filename="../ReText/window.py" line="84"/>
         <source>Edit toolbar</source>
         <translation>Barre d&apos;outil Édition</translation>
     </message>
     <message>
-        <location filename="window.py" line="89"/>
+        <location filename="../ReText/window.py" line="86"/>
         <source>Search toolbar</source>
         <translation>Barre d&apos;outil Recherche</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="../ReText/window.py" line="90"/>
         <source>New</source>
         <translation>Nouveau</translation>
     </message>
     <message>
-        <location filename="window.py" line="96"/>
+        <location filename="../ReText/window.py" line="93"/>
         <source>Open</source>
         <translation>Ouvrir</translation>
     </message>
     <message>
-        <location filename="window.py" line="99"/>
+        <location filename="../ReText/window.py" line="96"/>
         <source>Set encoding</source>
         <translation>Définir l&apos;encodage</translation>
     </message>
     <message>
-        <location filename="window.py" line="1096"/>
+        <location filename="../ReText/window.py" line="1190"/>
         <source>Reload</source>
         <translation>Recharger</translation>
     </message>
     <message>
-        <location filename="window.py" line="105"/>
+        <location filename="../ReText/window.py" line="102"/>
         <source>Save</source>
         <translation>Enregistrer</translation>
     </message>
     <message>
-        <location filename="window.py" line="109"/>
+        <location filename="../ReText/window.py" line="106"/>
         <source>Save as</source>
         <translation>Enregistrer Sous</translation>
     </message>
     <message>
-        <location filename="window.py" line="111"/>
+        <location filename="../ReText/window.py" line="108"/>
         <source>Next tab</source>
         <translation>Onglet suivant</translation>
     </message>
     <message>
-        <location filename="window.py" line="113"/>
+        <location filename="../ReText/window.py" line="110"/>
         <source>Previous tab</source>
         <translation>Onglet précédent</translation>
     </message>
     <message>
-        <location filename="window.py" line="115"/>
+        <location filename="../ReText/window.py" line="112"/>
+        <source>Close tab</source>
+        <translation>Fermer l&apos;onglet</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="114"/>
         <source>Print</source>
         <translation>Imprimer</translation>
     </message>
     <message>
-        <location filename="window.py" line="118"/>
+        <location filename="../ReText/window.py" line="117"/>
         <source>Print preview</source>
         <translation>Aperçu avant impression</translation>
     </message>
     <message>
-        <location filename="window.py" line="120"/>
+        <location filename="../ReText/window.py" line="119"/>
         <source>View HTML code</source>
         <translation>Voir le code HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="121"/>
-        <source>Change editor font</source>
-        <translation>Changer la police de l&apos;éditeur</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="123"/>
-        <source>Change preview font</source>
-        <translation>Changer la police de l&apos;aperçu</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="125"/>
+        <location filename="../ReText/window.py" line="124"/>
         <source>Find text</source>
         <translation>Rechercher un texte</translation>
     </message>
     <message>
-        <location filename="window.py" line="129"/>
+        <location filename="../ReText/window.py" line="129"/>
         <source>Preview</source>
         <translation>Aperçu</translation>
     </message>
     <message>
-        <location filename="window.py" line="139"/>
+        <location filename="../ReText/window.py" line="139"/>
         <source>Live preview</source>
         <translation>Aperçu dynamique</translation>
     </message>
     <message>
-        <location filename="window.py" line="144"/>
+        <location filename="../ReText/window.py" line="146"/>
         <source>Table editing mode</source>
         <translation>Mode édition table</translation>
     </message>
     <message>
-        <location filename="window.py" line="148"/>
+        <location filename="../ReText/window.py" line="152"/>
         <source>FakeVim mode</source>
         <translation>Imitation de Vim</translation>
     </message>
     <message>
-        <location filename="window.py" line="153"/>
+        <location filename="../ReText/window.py" line="157"/>
         <source>Fullscreen mode</source>
         <translation>Mode plein écran</translation>
     </message>
     <message>
-        <location filename="window.py" line="588"/>
+        <location filename="../ReText/window.py" line="630"/>
         <source>Preferences</source>
         <translation>Préférences</translation>
     </message>
     <message>
-        <location filename="window.py" line="163"/>
+        <location filename="../ReText/window.py" line="168"/>
         <source>Quit</source>
         <translation>Quitter</translation>
     </message>
     <message>
-        <location filename="window.py" line="166"/>
+        <location filename="../ReText/window.py" line="171"/>
         <source>Undo</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="window.py" line="168"/>
+        <location filename="../ReText/window.py" line="173"/>
         <source>Redo</source>
         <translation>Rétablir</translation>
     </message>
     <message>
-        <location filename="window.py" line="170"/>
+        <location filename="../ReText/window.py" line="175"/>
         <source>Copy</source>
         <translation>Copier</translation>
     </message>
     <message>
-        <location filename="window.py" line="172"/>
+        <location filename="../ReText/window.py" line="177"/>
         <source>Cut</source>
         <translation>Couper</translation>
     </message>
     <message>
-        <location filename="window.py" line="174"/>
+        <location filename="../ReText/window.py" line="179"/>
         <source>Paste</source>
         <translation>Coller</translation>
     </message>
     <message>
-        <location filename="window.py" line="184"/>
+        <location filename="../ReText/window.py" line="195"/>
         <source>Enable</source>
         <translation>Activer</translation>
     </message>
     <message>
-        <location filename="window.py" line="185"/>
+        <location filename="../ReText/window.py" line="196"/>
         <source>Set locale</source>
         <translation>Choisir la langue</translation>
     </message>
     <message>
-        <location filename="window.py" line="186"/>
+        <location filename="../ReText/window.py" line="197"/>
         <source>Use WebKit renderer</source>
         <translation>Utiliser le rendu de WebKit</translation>
     </message>
     <message>
-        <location filename="window.py" line="191"/>
-        <source>Use WebEngine (Chromium) renderer</source>
-        <translation>Utiliser le rendu de WebEngine (Chromium)</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="196"/>
+        <location filename="../ReText/window.py" line="207"/>
         <source>Show directory</source>
         <translation>Afficher le répertoire</translation>
     </message>
     <message>
-        <location filename="window.py" line="197"/>
+        <location filename="../ReText/window.py" line="208"/>
         <source>Next</source>
         <translation>Suivant</translation>
     </message>
     <message>
-        <location filename="window.py" line="199"/>
+        <location filename="../ReText/window.py" line="210"/>
         <source>Previous</source>
         <translation>Précédent</translation>
     </message>
     <message>
-        <location filename="window.py" line="201"/>
-        <source>Replace</source>
-        <translation>Remplacer</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="203"/>
-        <source>Replace all</source>
-        <translation>Remplacer tout</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="207"/>
-        <source>Close</source>
-        <translation>Fermer</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="210"/>
+        <location filename="../ReText/window.py" line="222"/>
         <source>Get help online</source>
         <translation>Assistance en ligne</translation>
     </message>
     <message>
-        <location filename="window.py" line="211"/>
+        <location filename="../ReText/window.py" line="223"/>
         <source>About ReText</source>
         <translation>À propos de ReText</translation>
     </message>
     <message>
-        <location filename="window.py" line="214"/>
+        <location filename="../ReText/window.py" line="226"/>
         <source>About Qt</source>
         <translation>À propos de Qt</translation>
     </message>
     <message>
-        <location filename="window.py" line="229"/>
+        <location filename="../ReText/window.py" line="241"/>
         <source>Bold</source>
         <translation>Gras</translation>
     </message>
     <message>
-        <location filename="window.py" line="231"/>
+        <location filename="../ReText/window.py" line="243"/>
         <source>Italic</source>
         <translation>Italique</translation>
     </message>
     <message>
-        <location filename="window.py" line="233"/>
+        <location filename="../ReText/window.py" line="245"/>
         <source>Underline</source>
         <translation>Souligné</translation>
     </message>
     <message>
-        <location filename="window.py" line="299"/>
-        <source>Formatting</source>
-        <translation>Formatage</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="245"/>
+        <location filename="../ReText/window.py" line="258"/>
         <source>Symbols</source>
         <translation>Symboles</translation>
     </message>
     <message>
-        <location filename="window.py" line="250"/>
+        <location filename="../ReText/window.py" line="263"/>
         <source>File</source>
         <translation>Fichier</translation>
     </message>
     <message>
-        <location filename="window.py" line="251"/>
+        <location filename="../ReText/window.py" line="264"/>
         <source>Edit</source>
         <translation>Édition</translation>
     </message>
     <message>
-        <location filename="window.py" line="252"/>
+        <location filename="../ReText/window.py" line="265"/>
         <source>Help</source>
         <translation>Aide</translation>
     </message>
     <message>
-        <location filename="window.py" line="255"/>
+        <location filename="../ReText/window.py" line="268"/>
         <source>Open recent</source>
         <translation>Ouvrir les fichiers récents</translation>
     </message>
     <message>
-        <location filename="window.py" line="267"/>
+        <location filename="../ReText/window.py" line="281"/>
         <source>Export</source>
         <translation>Exporter</translation>
     </message>
     <message>
-        <location filename="window.py" line="288"/>
+        <location filename="../ReText/window.py" line="306"/>
         <source>Spell check</source>
         <translation>Vérifier l&apos;orthographe</translation>
     </message>
     <message>
-        <location filename="window.py" line="296"/>
+        <location filename="../ReText/window.py" line="315"/>
         <source>Default markup</source>
         <translation>Balisage par défaut</translation>
     </message>
     <message>
-        <location filename="window.py" line="339"/>
+        <location filename="../ReText/window.py" line="318"/>
+        <source>Formatting</source>
+        <translation>Formatage</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="360"/>
         <source>Search</source>
         <translation>Rechercher</translation>
     </message>
     <message>
-        <location filename="window.py" line="342"/>
-        <source>Replace with</source>
-        <translation>Remplacer avec</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="344"/>
+        <location filename="../ReText/window.py" line="365"/>
         <source>Case sensitively</source>
         <translation>Sensible à la casse</translation>
     </message>
     <message>
-        <location filename="window.py" line="492"/>
+        <location filename="../ReText/window.py" line="526"/>
         <source>New document</source>
         <translation>Nouveau document</translation>
     </message>
     <message>
-        <location filename="window.py" line="664"/>
+        <location filename="../ReText/window.py" line="678"/>
+        <source>Go to line</source>
+        <translation>Aller à la ligne</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="678"/>
+        <source>Type the line number</source>
+        <translation>Entrer le numéro de ligne</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="714"/>
         <source>Please, save the file somewhere.</source>
         <translation>Veuillez enregistrer le fichier quelque part.</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="830"/>
         <source>Select one or several files to open</source>
         <translation>Choisir un ou plusieurs fichiers à ouvrir</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="1248"/>
         <source>Supported files</source>
         <translation>Formats acceptés</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="1248"/>
         <source>All files (*)</source>
         <translation>Tous les fichiers (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="818"/>
+        <location filename="../ReText/window.py" line="869"/>
         <source>Select file encoding from the list:</source>
         <translation>Choisir l&apos;encodage du fichier dans la liste:</translation>
     </message>
     <message>
-        <location filename="window.py" line="839"/>
+        <location filename="../ReText/window.py" line="892"/>
         <source>Plain text (*.txt)</source>
         <translation>Fichiers texte (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="842"/>
+        <location filename="../ReText/window.py" line="895"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>Fichiers %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="919"/>
+        <location filename="../ReText/window.py" line="970"/>
         <source>Save file</source>
         <translation>Enregistrer le fichier</translation>
     </message>
     <message>
-        <location filename="window.py" line="860"/>
-        <source>Cannot save to file which is open in another tab!</source>
-        <translation>Impossible d&apos;enregistrer un fichier ouvert dans un autre onglet!</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="884"/>
+        <location filename="../ReText/window.py" line="938"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Impossible d&apos;enregistrer le fichier car il est en lecture seule !</translation>
     </message>
     <message>
-        <location filename="window.py" line="909"/>
+        <location filename="../ReText/window.py" line="960"/>
         <source>Export document to ODT</source>
         <translation>Exporter le document au format ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="909"/>
+        <location filename="../ReText/window.py" line="960"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Fichiers OpenDocument texte (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="919"/>
+        <location filename="../ReText/window.py" line="970"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Fichiers HTML (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="940"/>
+        <location filename="../ReText/window.py" line="1019"/>
         <source>Export document to PDF</source>
         <translation>Exporter le document au format PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="940"/>
+        <location filename="../ReText/window.py" line="1019"/>
         <source>PDF files (*.pdf)</source>
         <translation>Fichiers PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="960"/>
+        <location filename="../ReText/window.py" line="1046"/>
         <source>Print document</source>
         <translation>Imprimer le document</translation>
     </message>
     <message>
-        <location filename="window.py" line="984"/>
+        <location filename="../ReText/window.py" line="1069"/>
         <source>Export document</source>
         <translation>Exporter le document</translation>
     </message>
     <message>
-        <location filename="window.py" line="1005"/>
+        <location filename="../ReText/window.py" line="1090"/>
         <source>Failed to execute the command:</source>
         <translation>Échec lors de l&apos;exécution de la commande :</translation>
     </message>
     <message>
-        <location filename="window.py" line="1039"/>
-        <source>Alt text</source>
-        <translation>Texte alternatif</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1040"/>
-        <source>URL</source>
-        <translation>URL</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1040"/>
-        <source>Link text</source>
-        <translation>Texte du lien</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1080"/>
+        <location filename="../ReText/window.py" line="1173"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
         <translation>Ce fichier a été supprimé par une autre application.
 Pensez à vérifier que vous sauvegardez le fichier avant de quitter.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1087"/>
+        <location filename="../ReText/window.py" line="1181"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
@@ -573,51 +628,168 @@ Voulez-vous recharger le fichier (vos modifications seront perdues) ?
 </translation>
     </message>
     <message>
-        <location filename="window.py" line="1092"/>
+        <location filename="../ReText/window.py" line="1186"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
         <translation>Si vous choisissez de ne pas recharger le fichier, la sauvegarde automatique sera désactivée pour cette session afin d&apos;éviter une perte de données.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1116"/>
+        <location filename="../ReText/window.py" line="1210"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Le document a été modifié.
 Voulez vous enregistrer vos changements ?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1145"/>
+        <location filename="../ReText/window.py" line="1238"/>
         <source>HTML code</source>
         <translation>Code HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
-        <source>ReText %s (using PyMarkups %s)</source>
-        <translation>ReText %s (utilisant PyMarkups %s)</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Éditeur de Markdown et reStructuredText simple mais puissant</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Auteur: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Website</source>
         <translation>Site Web</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Markdown syntax</source>
         <translation>Syntaxe Markdown</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>reStructuredText syntax</source>
         <translation>Syntaxe reStructuredText</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="120"/>
+        <source>Change editor font</source>
+        <translation>Changer la police de l&apos;éditeur</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="122"/>
+        <source>Change preview font</source>
+        <translation>Changer la police de l&apos;aperçu</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="1266"/>
+        <source>ReText %s (using PyMarkups %s)</source>
+        <translation>ReText %s (utilisant PyMarkups %s)</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="218"/>
+        <source>Close</source>
+        <translation>Fermer</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="1131"/>
+        <source>Alt text</source>
+        <translation>Texte alternatif</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="1132"/>
+        <source>URL</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="1132"/>
+        <source>Link text</source>
+        <translation>Texte du lien</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="212"/>
+        <source>Replace</source>
+        <translation>Remplacer</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="214"/>
+        <source>Replace all</source>
+        <translation>Remplacer tout</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="363"/>
+        <source>Replace with</source>
+        <translation>Remplacer avec</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="915"/>
+        <source>Cannot save to file which is open in another tab!</source>
+        <translation>Impossible d&apos;enregistrer un fichier ouvert dans un autre onglet!</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="202"/>
+        <source>Use WebEngine (Chromium) renderer</source>
+        <translation>Utiliser le rendu de WebEngine (Chromium)</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="144"/>
+        <source>Insert table</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="149"/>
+        <source>Insert images by file path</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="181"/>
+        <source>Paste image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="183"/>
+        <source>Move line up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="185"/>
+        <source>Move line down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="993"/>
+        <source>Unrecognized paperSize setting &quot;%s&quot;.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="1248"/>
+        <source>Select one or several images to open</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>TextInfoArea</name>
+    <message>
+        <location filename="../ReText/editor.py" line="582"/>
+        <source>%d w | %d a | %d c</source>
+        <comment>count of words, alphanumeric characters, all characters</comment>
+        <translation type="unfinished">%d m | %d a | %d c</translation>
+    </message>
+</context>
+<context>
+    <name>main</name>
+    <message>
+        <location filename="../ReText/__main__.py" line="77"/>
+        <source>Open the files in preview mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/__main__.py" line="79"/>
+        <source>Create a new window even if there is an existing one</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/__main__.py" line="83"/>
+        <source>List of files to open</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
