@@ -3,118 +3,186 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="80"/>
+        <source>Using configuration file at:</source>
+        <translation>File di configurazione utilizzato:</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Behavior</source>
         <translation>Comportamento</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
-        <source>Automatically open last documents on startup</source>
-        <translation>Apri automaticamente gli ultimi documenti utilizzati all&apos;avvio</translation>
-    </message>
-    <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Automatically save documents</source>
         <translation>Salva automaticamente documenti</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Automatically open last documents on startup</source>
+        <translation>Apri automaticamente gli ultimi documenti utilizzati all&apos;avvio</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Number of recent documents</source>
+        <translation>Numero di documenti recenti</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Restore window geometry</source>
         <translation>Ripristina dimensioni finestra</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
-        <source>Use live preview by default</source>
-        <translation>Utilizza anteprima in tempo reale per impostazione predefinita</translation>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Default preview state</source>
+        <translation>Stato predefinito anteprima</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Open external links in ReText window</source>
         <translation>Apri collegamenti esterni nella finestra di ReText</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Markdown syntax extensions (comma-separated)</source>
         <translation>Estensioni alla sintassi Markdown (separate da virgole)</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Enable synchronized scrolling for Markdown</source>
         <translation>Abilita scorrimento sincronizzato per Markdown</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="169"/>
         <source>Editor</source>
         <translation>Editor</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Highlight current line</source>
         <translation>Evidenzia riga corrente</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Show line numbers</source>
         <translation>Visualizza numeri di riga</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Line numbers are relative to current line</source>
+        <translation>I numeri di riga sono relativi alla riga corrente</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Tab key inserts spaces</source>
         <translation>Il tasto Tab inserisce spazi</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Tabulation width</source>
         <translation>Larghezza di tabulazione</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Draw vertical line at column</source>
         <translation>Traccia riga verticale alla colonna</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Enable soft wrap</source>
+        <translation>Abilita ritorno a capo automatico</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Show document stats</source>
+        <translation>Visualizza statistiche documento</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Interface</source>
         <translation>Interfaccia</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Hide toolbar</source>
+        <translation>Nascondi barra degli strumenti</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Icon theme name</source>
         <translation>Nome tema icone</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Stylesheet file</source>
         <translation>File foglio di stile</translation>
     </message>
     <message>
-        <location filename="config.py" line="104"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Hide tabs bar when there is only one tab</source>
+        <translation>Nascondi barra delle schede quando c&apos;è solo una scheda</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Show full path in window title</source>
+        <translation>Visualizza percorso completo nella barra del titolo</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="151"/>
         <source>Help</source>
         <translation>Aiuto</translation>
     </message>
+    <message>
+        <location filename="../ReText/config.py" line="170"/>
+        <source>Live preview</source>
+        <translation>Anteprima in tempo reale</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="171"/>
+        <source>Normal preview</source>
+        <translation>Anteprima normale</translation>
+    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
     <message>
-        <location filename="config.py" line="34"/>
+        <location filename="../ReText/config.py" line="35"/>
         <source>(none)</source>
         <translation>(nessuno)</translation>
     </message>
     <message>
-        <location filename="config.py" line="41"/>
+        <location filename="../ReText/config.py" line="42"/>
         <source>Select file to open</source>
         <translation>Seleziona il file da aprire</translation>
     </message>
 </context>
+<context>
+    <name>InsertTableDialog</name>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="27"/>
+        <source>Insert table</source>
+        <translation>Inserisci tabella</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="36"/>
+        <source>Number of rows</source>
+        <translation>Numero di righe</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="37"/>
+        <source>Number of columns</source>
+        <translation>Numero di colonne</translation>
+    </message>
+</context>
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="dialogs.py" line="44"/>
+        <location filename="../ReText/dialogs.py" line="44"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>Inserisci localizzazione (esempio: en_US)</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="50"/>
+        <location filename="../ReText/dialogs.py" line="50"/>
         <source>Set as default</source>
         <translation>Imposta come predefinito</translation>
     </message>
@@ -122,12 +190,12 @@
 <context>
     <name>Proxy</name>
     <message>
-        <location filename="fakevimeditor.py" line="64"/>
+        <location filename="../ReText/fakevimeditor.py" line="61"/>
         <source>No write since last change (add ! to override)</source>
         <translation>Nessuna scrittura dall&apos;ultima modifica (aggiungi ! per salvare comunque)</translation>
     </message>
     <message>
-        <location filename="fakevimeditor.py" line="121"/>
+        <location filename="../ReText/fakevimeditor.py" line="118"/>
         <source>Information</source>
         <translation>Informazione</translation>
     </message>
@@ -135,12 +203,17 @@
 <context>
     <name>ReTextEdit</name>
     <message>
-        <location filename="editor.py" line="292"/>
+        <location filename="../ReText/editor.py" line="212"/>
+        <source>Add to dictionary</source>
+        <translation>Aggiungi al dizionario</translation>
+    </message>
+    <message>
+        <location filename="../ReText/editor.py" line="391"/>
         <source>Save image</source>
         <translation>Salva immagine</translation>
     </message>
     <message>
-        <location filename="editor.py" line="292"/>
+        <location filename="../ReText/editor.py" line="391"/>
         <source>Images (*.png *.jpg)</source>
         <translation>Immagini (*.png *.jpg)</translation>
     </message>
@@ -148,423 +221,487 @@
 <context>
     <name>ReTextTab</name>
     <message>
-        <location filename="tab.py" line="183"/>
+        <location filename="../ReText/tab.py" line="184"/>
         <source>New document</source>
         <translation>Nuovo documento</translation>
     </message>
     <message>
-        <location filename="tab.py" line="188"/>
+        <location filename="../ReText/tab.py" line="189"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation>Impossibile interpretare i contenuti del file, controlla che il &lt;a href=&quot;%s&quot;&gt;modulo richiesto&lt;/a&gt; sia installato!</translation>
     </message>
+    <message>
+        <location filename="../ReText/tab.py" line="478"/>
+        <source>Create missing file?</source>
+        <translation>Creare il file mancante?</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="478"/>
+        <source>The file &apos;%s&apos; does not exist.
+
+Do you want to create it?</source>
+        <translation>Il file &apos;%s&apos; non esiste.
+
+Crearlo?</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="511"/>
+        <source>File could not be created</source>
+        <translation>Impossibile creare il file</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="511"/>
+        <source>Could not create file &apos;%s&apos;: %s</source>
+        <translation>Impossibile creare il file &apos;%s&apos;: %s</translation>
+    </message>
 </context>
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="85"/>
+        <location filename="../ReText/window.py" line="82"/>
         <source>File toolbar</source>
         <translation>Barra degli strumenti File</translation>
     </message>
     <message>
-        <location filename="window.py" line="87"/>
+        <location filename="../ReText/window.py" line="84"/>
         <source>Edit toolbar</source>
         <translation>Barra degli strumenti Modifica</translation>
     </message>
     <message>
-        <location filename="window.py" line="89"/>
+        <location filename="../ReText/window.py" line="86"/>
         <source>Search toolbar</source>
         <translation>Barra degli strumenti Ricerca</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="../ReText/window.py" line="90"/>
         <source>New</source>
         <translation>Nuovo</translation>
     </message>
     <message>
-        <location filename="window.py" line="96"/>
+        <location filename="../ReText/window.py" line="93"/>
         <source>Open</source>
         <translation>Apri</translation>
     </message>
     <message>
-        <location filename="window.py" line="99"/>
+        <location filename="../ReText/window.py" line="96"/>
         <source>Set encoding</source>
         <translation>Imposta codifica</translation>
     </message>
     <message>
-        <location filename="window.py" line="1096"/>
+        <location filename="../ReText/window.py" line="1190"/>
         <source>Reload</source>
         <translation>Ricarica</translation>
     </message>
     <message>
-        <location filename="window.py" line="105"/>
+        <location filename="../ReText/window.py" line="102"/>
         <source>Save</source>
         <translation>Salva</translation>
     </message>
     <message>
-        <location filename="window.py" line="109"/>
+        <location filename="../ReText/window.py" line="106"/>
         <source>Save as</source>
         <translation>Salva con nome</translation>
     </message>
     <message>
-        <location filename="window.py" line="111"/>
+        <location filename="../ReText/window.py" line="108"/>
         <source>Next tab</source>
         <translation>Scheda successiva</translation>
     </message>
     <message>
-        <location filename="window.py" line="113"/>
+        <location filename="../ReText/window.py" line="110"/>
         <source>Previous tab</source>
         <translation>Scheda precedente</translation>
     </message>
     <message>
-        <location filename="window.py" line="115"/>
+        <location filename="../ReText/window.py" line="112"/>
+        <source>Close tab</source>
+        <translation>Chiudi scheda</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="114"/>
         <source>Print</source>
         <translation>Stampa</translation>
     </message>
     <message>
-        <location filename="window.py" line="118"/>
+        <location filename="../ReText/window.py" line="117"/>
         <source>Print preview</source>
         <translation>Anteprima di stampa</translation>
     </message>
     <message>
-        <location filename="window.py" line="120"/>
+        <location filename="../ReText/window.py" line="119"/>
         <source>View HTML code</source>
         <translation>Visualizza codice HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="121"/>
+        <location filename="../ReText/window.py" line="120"/>
         <source>Change editor font</source>
         <translation>Modifica carattere editor</translation>
     </message>
     <message>
-        <location filename="window.py" line="123"/>
+        <location filename="../ReText/window.py" line="122"/>
         <source>Change preview font</source>
         <translation>Modifica carattere anteprima</translation>
     </message>
     <message>
-        <location filename="window.py" line="125"/>
+        <location filename="../ReText/window.py" line="124"/>
         <source>Find text</source>
         <translation>Trova testo</translation>
     </message>
     <message>
-        <location filename="window.py" line="129"/>
+        <location filename="../ReText/window.py" line="678"/>
+        <source>Go to line</source>
+        <translation>Vai alla riga</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="129"/>
         <source>Preview</source>
         <translation>Anteprima</translation>
     </message>
     <message>
-        <location filename="window.py" line="139"/>
+        <location filename="../ReText/window.py" line="139"/>
         <source>Live preview</source>
         <translation>Anteprima in tempo reale</translation>
     </message>
     <message>
-        <location filename="window.py" line="144"/>
+        <location filename="../ReText/window.py" line="144"/>
+        <source>Insert table</source>
+        <translation>Inserisci tabella</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="146"/>
         <source>Table editing mode</source>
         <translation>Modalità modifica tabella</translation>
     </message>
     <message>
-        <location filename="window.py" line="148"/>
+        <location filename="../ReText/window.py" line="152"/>
         <source>FakeVim mode</source>
         <translation>Modalità di inserimento Vim</translation>
     </message>
     <message>
-        <location filename="window.py" line="153"/>
+        <location filename="../ReText/window.py" line="157"/>
         <source>Fullscreen mode</source>
         <translation>Schermo intero</translation>
     </message>
     <message>
-        <location filename="window.py" line="588"/>
+        <location filename="../ReText/window.py" line="630"/>
         <source>Preferences</source>
         <translation>Preferenze</translation>
     </message>
     <message>
-        <location filename="window.py" line="163"/>
+        <location filename="../ReText/window.py" line="168"/>
         <source>Quit</source>
         <translation>Esci</translation>
     </message>
     <message>
-        <location filename="window.py" line="166"/>
+        <location filename="../ReText/window.py" line="171"/>
         <source>Undo</source>
         <translation>Annulla</translation>
     </message>
     <message>
-        <location filename="window.py" line="168"/>
+        <location filename="../ReText/window.py" line="173"/>
         <source>Redo</source>
         <translation>Ripristina</translation>
     </message>
     <message>
-        <location filename="window.py" line="170"/>
+        <location filename="../ReText/window.py" line="175"/>
         <source>Copy</source>
         <translation>Copia</translation>
     </message>
     <message>
-        <location filename="window.py" line="172"/>
+        <location filename="../ReText/window.py" line="177"/>
         <source>Cut</source>
         <translation>Taglia</translation>
     </message>
     <message>
-        <location filename="window.py" line="174"/>
+        <location filename="../ReText/window.py" line="179"/>
         <source>Paste</source>
         <translation>Incolla</translation>
     </message>
     <message>
-        <location filename="window.py" line="184"/>
+        <location filename="../ReText/window.py" line="181"/>
+        <source>Paste image</source>
+        <translation>Incolla immagine</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="183"/>
+        <source>Move line up</source>
+        <translation>Sposta riga in su</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="185"/>
+        <source>Move line down</source>
+        <translation>Sposta riga in giù</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="195"/>
         <source>Enable</source>
         <translation>Attiva</translation>
     </message>
     <message>
-        <location filename="window.py" line="185"/>
+        <location filename="../ReText/window.py" line="196"/>
         <source>Set locale</source>
         <translation>Imposta localizzazione</translation>
     </message>
     <message>
-        <location filename="window.py" line="186"/>
+        <location filename="../ReText/window.py" line="197"/>
         <source>Use WebKit renderer</source>
         <translation>Usa il motore WebKit</translation>
     </message>
     <message>
-        <location filename="window.py" line="191"/>
+        <location filename="../ReText/window.py" line="202"/>
         <source>Use WebEngine (Chromium) renderer</source>
         <translation>Utilizza renderer WebEngine (Chromium)</translation>
     </message>
     <message>
-        <location filename="window.py" line="196"/>
+        <location filename="../ReText/window.py" line="207"/>
         <source>Show directory</source>
         <translation>Mostra cartella</translation>
     </message>
     <message>
-        <location filename="window.py" line="197"/>
+        <location filename="../ReText/window.py" line="208"/>
         <source>Next</source>
         <translation>Avanti</translation>
     </message>
     <message>
-        <location filename="window.py" line="199"/>
+        <location filename="../ReText/window.py" line="210"/>
         <source>Previous</source>
         <translation>Indietro</translation>
     </message>
     <message>
-        <location filename="window.py" line="201"/>
+        <location filename="../ReText/window.py" line="212"/>
         <source>Replace</source>
         <translation>Sostituisci</translation>
     </message>
     <message>
-        <location filename="window.py" line="203"/>
+        <location filename="../ReText/window.py" line="214"/>
         <source>Replace all</source>
         <translation>Sostituisci tutto</translation>
     </message>
     <message>
-        <location filename="window.py" line="207"/>
+        <location filename="../ReText/window.py" line="218"/>
         <source>Close</source>
         <translation>Chiudi</translation>
     </message>
     <message>
-        <location filename="window.py" line="210"/>
+        <location filename="../ReText/window.py" line="222"/>
         <source>Get help online</source>
         <translation>Ottieni aiuto online</translation>
     </message>
     <message>
-        <location filename="window.py" line="211"/>
+        <location filename="../ReText/window.py" line="223"/>
         <source>About ReText</source>
         <translation>Informazioni su ReText</translation>
     </message>
     <message>
-        <location filename="window.py" line="214"/>
+        <location filename="../ReText/window.py" line="226"/>
         <source>About Qt</source>
         <translation>Informazioni su Qt</translation>
     </message>
     <message>
-        <location filename="window.py" line="229"/>
+        <location filename="../ReText/window.py" line="241"/>
         <source>Bold</source>
         <translation>Grassetto</translation>
     </message>
     <message>
-        <location filename="window.py" line="231"/>
+        <location filename="../ReText/window.py" line="243"/>
         <source>Italic</source>
         <translation>Corsivo</translation>
     </message>
     <message>
-        <location filename="window.py" line="233"/>
+        <location filename="../ReText/window.py" line="245"/>
         <source>Underline</source>
         <translation>Sottolineato</translation>
     </message>
     <message>
-        <location filename="window.py" line="299"/>
+        <location filename="../ReText/window.py" line="318"/>
         <source>Formatting</source>
         <translation>Formattazione</translation>
     </message>
     <message>
-        <location filename="window.py" line="245"/>
+        <location filename="../ReText/window.py" line="258"/>
         <source>Symbols</source>
         <translation>Simboli</translation>
     </message>
     <message>
-        <location filename="window.py" line="250"/>
+        <location filename="../ReText/window.py" line="263"/>
         <source>File</source>
         <translation>File</translation>
     </message>
     <message>
-        <location filename="window.py" line="251"/>
+        <location filename="../ReText/window.py" line="264"/>
         <source>Edit</source>
         <translation>Modifica</translation>
     </message>
     <message>
-        <location filename="window.py" line="252"/>
+        <location filename="../ReText/window.py" line="265"/>
         <source>Help</source>
         <translation>Aiuto</translation>
     </message>
     <message>
-        <location filename="window.py" line="255"/>
+        <location filename="../ReText/window.py" line="268"/>
         <source>Open recent</source>
         <translation>Apri recente</translation>
     </message>
     <message>
-        <location filename="window.py" line="267"/>
+        <location filename="../ReText/window.py" line="281"/>
         <source>Export</source>
         <translation>Esporta</translation>
     </message>
     <message>
-        <location filename="window.py" line="288"/>
+        <location filename="../ReText/window.py" line="306"/>
         <source>Spell check</source>
         <translation>Correttore ortografico</translation>
     </message>
     <message>
-        <location filename="window.py" line="296"/>
+        <location filename="../ReText/window.py" line="315"/>
         <source>Default markup</source>
         <translation>Linguaggio a marcatori predefinito</translation>
     </message>
     <message>
-        <location filename="window.py" line="339"/>
+        <location filename="../ReText/window.py" line="360"/>
         <source>Search</source>
         <translation>Cerca</translation>
     </message>
     <message>
-        <location filename="window.py" line="342"/>
+        <location filename="../ReText/window.py" line="363"/>
         <source>Replace with</source>
         <translation>Sostituisci con</translation>
     </message>
     <message>
-        <location filename="window.py" line="344"/>
+        <location filename="../ReText/window.py" line="365"/>
         <source>Case sensitively</source>
         <translation>Distingui maiuscole/minuscole</translation>
     </message>
     <message>
-        <location filename="window.py" line="492"/>
+        <location filename="../ReText/window.py" line="526"/>
         <source>New document</source>
         <translation>Nuovo documento</translation>
     </message>
     <message>
-        <location filename="window.py" line="664"/>
+        <location filename="../ReText/window.py" line="678"/>
+        <source>Type the line number</source>
+        <translation>Digitare il numero di riga</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="714"/>
         <source>Please, save the file somewhere.</source>
         <translation>Per favore, salva il file da qualche parte.</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="830"/>
         <source>Select one or several files to open</source>
         <translation>Seleziona uno o più file da aprire</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="1248"/>
         <source>Supported files</source>
         <translation>File supportati</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="1248"/>
         <source>All files (*)</source>
         <translation>Tutti i file (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="818"/>
+        <location filename="../ReText/window.py" line="869"/>
         <source>Select file encoding from the list:</source>
         <translation>Seleziona la codifica del file dall&apos;elenco:</translation>
     </message>
     <message>
-        <location filename="window.py" line="839"/>
+        <location filename="../ReText/window.py" line="892"/>
         <source>Plain text (*.txt)</source>
         <translation>Testo semplice (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="842"/>
+        <location filename="../ReText/window.py" line="895"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>File %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="919"/>
+        <location filename="../ReText/window.py" line="970"/>
         <source>Save file</source>
         <translation>Salva file</translation>
     </message>
     <message>
-        <location filename="window.py" line="860"/>
+        <location filename="../ReText/window.py" line="915"/>
         <source>Cannot save to file which is open in another tab!</source>
         <translation>Impossibile salvare in un file aperto in un&apos;altra scheda!</translation>
     </message>
     <message>
-        <location filename="window.py" line="884"/>
+        <location filename="../ReText/window.py" line="938"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Impossibile salvare il file perché è in sola lettura!</translation>
     </message>
     <message>
-        <location filename="window.py" line="909"/>
+        <location filename="../ReText/window.py" line="960"/>
         <source>Export document to ODT</source>
         <translation>Esporta documento nel formato ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="909"/>
+        <location filename="../ReText/window.py" line="960"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>File di testo OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="919"/>
+        <location filename="../ReText/window.py" line="970"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>File HTML (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="940"/>
+        <location filename="../ReText/window.py" line="993"/>
+        <source>Unrecognized paperSize setting &quot;%s&quot;.</source>
+        <translation>Impostazione paperSize &quot;%s&quot; non riconosciuta.</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="1019"/>
         <source>Export document to PDF</source>
         <translation>Esporta documento nel formato PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="940"/>
+        <location filename="../ReText/window.py" line="1019"/>
         <source>PDF files (*.pdf)</source>
         <translation>File PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="960"/>
+        <location filename="../ReText/window.py" line="1046"/>
         <source>Print document</source>
         <translation>Stampa documento</translation>
     </message>
     <message>
-        <location filename="window.py" line="984"/>
+        <location filename="../ReText/window.py" line="1069"/>
         <source>Export document</source>
         <translation>Esporta documento</translation>
     </message>
     <message>
-        <location filename="window.py" line="1005"/>
+        <location filename="../ReText/window.py" line="1090"/>
         <source>Failed to execute the command:</source>
         <translation>Impossibile eseguire il comando:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1039"/>
+        <location filename="../ReText/window.py" line="1131"/>
         <source>Alt text</source>
         <translation>Testo alternativo</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="../ReText/window.py" line="1132"/>
         <source>URL</source>
         <translation>URL</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="../ReText/window.py" line="1132"/>
         <source>Link text</source>
         <translation>Testo collegamento</translation>
     </message>
     <message>
-        <location filename="window.py" line="1080"/>
+        <location filename="../ReText/window.py" line="1173"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
         <translation>Questo file è stato eliminato da un&apos;altra applicazione.
 Assicurati di salvare il file prima di uscire.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1087"/>
+        <location filename="../ReText/window.py" line="1181"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
@@ -573,51 +710,88 @@ Vuoi ricaricare il file (ciò comporterà la perdita di tutti i cambiamenti)?
 </translation>
     </message>
     <message>
-        <location filename="window.py" line="1092"/>
+        <location filename="../ReText/window.py" line="1186"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
         <translation>Se scegli di non ricaricare il file, la modalità salvataggio automatico sarà disabilitata per questa sessione per prevenire perdite di dati.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1116"/>
+        <location filename="../ReText/window.py" line="1210"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Il documento è stato modificato.
 Vuoi salvare le modifiche?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1145"/>
+        <location filename="../ReText/window.py" line="1238"/>
         <source>HTML code</source>
         <translation>Codice HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>ReText %s (using PyMarkups %s)</source>
         <translation>ReText %s (utilizza PyMarkups %s)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Un editor semplice ma potente per Markdown e reStructuredText</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Autore: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Website</source>
         <translation>Sito Web</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Markdown syntax</source>
         <translation>Sintassi Markdown</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>reStructuredText syntax</source>
         <translation>Sintassi reStructuredText</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="149"/>
+        <source>Insert images by file path</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="1248"/>
+        <source>Select one or several images to open</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>TextInfoArea</name>
+    <message>
+        <location filename="../ReText/editor.py" line="582"/>
+        <source>%d w | %d a | %d c</source>
+        <comment>count of words, alphanumeric characters, all characters</comment>
+        <translation>%d p | %d a | %d c</translation>
+    </message>
+</context>
+<context>
+    <name>main</name>
+    <message>
+        <location filename="../ReText/__main__.py" line="77"/>
+        <source>Open the files in preview mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/__main__.py" line="79"/>
+        <source>Create a new window even if there is an existing one</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/__main__.py" line="83"/>
+        <source>List of files to open</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
