@@ -3,118 +3,186 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="80"/>
+        <source>Using configuration file at:</source>
+        <translation>Используются настройки из файла:</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Behavior</source>
         <translation>Поведение</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Automatically save documents</source>
         <translation>Автоматически сохранять документы</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Automatically open last documents on startup</source>
         <translation>Автоматически открывать последние документы при запуске</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Number of recent documents</source>
+        <translation>Число последних документов</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Restore window geometry</source>
         <translation>Сохранять геометрию окна</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
-        <source>Use live preview by default</source>
-        <translation>Включить живой просмотр по умолчанию</translation>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Default preview state</source>
+        <translation>Режим отображения по умолчанию</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Open external links in ReText window</source>
         <translation>Открывать внешние ссылки в окне ReText</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Markdown syntax extensions (comma-separated)</source>
         <translation>Расширения синтаксиса Markdown (разделённые запятыми)</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Enable synchronized scrolling for Markdown</source>
         <translation>Включить синхронную прокрутку для Markdown</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="169"/>
         <source>Editor</source>
         <translation>Редактор</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Highlight current line</source>
         <translation>Подсвечивать текущую строку</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Show line numbers</source>
         <translation>Показывать номера строк</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Line numbers are relative to current line</source>
+        <translation>Начинать нумерацию строк с текущей строки</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Tab key inserts spaces</source>
         <translation>Tab вставляет пробелы</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Tabulation width</source>
         <translation>Ширина табуляции</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Draw vertical line at column</source>
         <translation>Рисовать вертикальную линию в столбце</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Enable soft wrap</source>
+        <translation>Переносить строки</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Show document stats</source>
+        <translation>Отображать статистику документа</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Interface</source>
         <translation>Внешний вид</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Hide toolbar</source>
+        <translation>Скрыть панель инструментов</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Icon theme name</source>
         <translation>Тема значков</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Stylesheet file</source>
         <translation>Файл стиля Qt</translation>
     </message>
     <message>
-        <location filename="config.py" line="104"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Hide tabs bar when there is only one tab</source>
+        <translation>Скрыть панель вкладок, если вкладка всего одна</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Show full path in window title</source>
+        <translation>Показывать полный путь в заголовке окна</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="151"/>
         <source>Help</source>
         <translation>Справка</translation>
     </message>
+    <message>
+        <location filename="../ReText/config.py" line="170"/>
+        <source>Live preview</source>
+        <translation>Живой просмотр</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="171"/>
+        <source>Normal preview</source>
+        <translation>Обычный просмотр</translation>
+    </message>
 </context>
 <context>
     <name>FileSelectButton</name>
     <message>
-        <location filename="config.py" line="34"/>
+        <location filename="../ReText/config.py" line="35"/>
         <source>(none)</source>
         <translation>(не выбран)</translation>
     </message>
     <message>
-        <location filename="config.py" line="41"/>
+        <location filename="../ReText/config.py" line="42"/>
         <source>Select file to open</source>
         <translation>Выберите файл для открытия</translation>
     </message>
 </context>
+<context>
+    <name>InsertTableDialog</name>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="27"/>
+        <source>Insert table</source>
+        <translation>Вставить таблицу</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="36"/>
+        <source>Number of rows</source>
+        <translation>Число строк</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="37"/>
+        <source>Number of columns</source>
+        <translation>Число столбцов</translation>
+    </message>
+</context>
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="dialogs.py" line="44"/>
+        <location filename="../ReText/dialogs.py" line="44"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>Введите код локали (например: en_US)</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="50"/>
+        <location filename="../ReText/dialogs.py" line="50"/>
         <source>Set as default</source>
         <translation>Установить по умолчанию</translation>
     </message>
@@ -122,12 +190,12 @@
 <context>
     <name>Proxy</name>
     <message>
-        <location filename="fakevimeditor.py" line="64"/>
+        <location filename="../ReText/fakevimeditor.py" line="61"/>
         <source>No write since last change (add ! to override)</source>
         <translation>Есть несохранённые изменения (добавьте ! для игнорирования)</translation>
     </message>
     <message>
-        <location filename="fakevimeditor.py" line="121"/>
+        <location filename="../ReText/fakevimeditor.py" line="118"/>
         <source>Information</source>
         <translation>Информация</translation>
     </message>
@@ -135,12 +203,17 @@
 <context>
     <name>ReTextEdit</name>
     <message>
-        <location filename="editor.py" line="292"/>
+        <location filename="../ReText/editor.py" line="212"/>
+        <source>Add to dictionary</source>
+        <translation>Добавить в словарь</translation>
+    </message>
+    <message>
+        <location filename="../ReText/editor.py" line="391"/>
         <source>Save image</source>
         <translation>Сохранить изображение</translation>
     </message>
     <message>
-        <location filename="editor.py" line="292"/>
+        <location filename="../ReText/editor.py" line="391"/>
         <source>Images (*.png *.jpg)</source>
         <translation>Изображения (*.png *.jpg)</translation>
     </message>
@@ -148,423 +221,487 @@
 <context>
     <name>ReTextTab</name>
     <message>
-        <location filename="tab.py" line="183"/>
+        <location filename="../ReText/tab.py" line="184"/>
         <source>New document</source>
         <translation>Новый документ</translation>
     </message>
     <message>
-        <location filename="tab.py" line="188"/>
+        <location filename="../ReText/tab.py" line="189"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation>Не удалось обработать содержимое файла, убедитесь, что установлен &lt;a href=&quot;%s&quot;&gt;необходимый модуль&lt;/a&gt;!</translation>
     </message>
+    <message>
+        <location filename="../ReText/tab.py" line="478"/>
+        <source>Create missing file?</source>
+        <translation>Создать недостающий файл?</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="478"/>
+        <source>The file &apos;%s&apos; does not exist.
+
+Do you want to create it?</source>
+        <translation>Файла «%s» не существует.
+
+Вы хотите создать его?</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="511"/>
+        <source>File could not be created</source>
+        <translation>Не удалось создать файл</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="511"/>
+        <source>Could not create file &apos;%s&apos;: %s</source>
+        <translation>Не удалось создать файл «%s»: %s</translation>
+    </message>
 </context>
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="85"/>
+        <location filename="../ReText/window.py" line="82"/>
         <source>File toolbar</source>
         <translation>Панель файла</translation>
     </message>
     <message>
-        <location filename="window.py" line="87"/>
+        <location filename="../ReText/window.py" line="84"/>
         <source>Edit toolbar</source>
         <translation>Панель редактирования</translation>
     </message>
     <message>
-        <location filename="window.py" line="89"/>
+        <location filename="../ReText/window.py" line="86"/>
         <source>Search toolbar</source>
         <translation>Панель поиска</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="../ReText/window.py" line="90"/>
         <source>New</source>
         <translation>Новый</translation>
     </message>
     <message>
-        <location filename="window.py" line="96"/>
+        <location filename="../ReText/window.py" line="93"/>
         <source>Open</source>
         <translation>Открыть</translation>
     </message>
     <message>
-        <location filename="window.py" line="99"/>
+        <location filename="../ReText/window.py" line="96"/>
         <source>Set encoding</source>
         <translation>Установить кодировку</translation>
     </message>
     <message>
-        <location filename="window.py" line="1096"/>
+        <location filename="../ReText/window.py" line="1190"/>
         <source>Reload</source>
         <translation>Загрузить заново</translation>
     </message>
     <message>
-        <location filename="window.py" line="105"/>
+        <location filename="../ReText/window.py" line="102"/>
         <source>Save</source>
         <translation>Сохранить</translation>
     </message>
     <message>
-        <location filename="window.py" line="109"/>
+        <location filename="../ReText/window.py" line="106"/>
         <source>Save as</source>
         <translation>Сохранить как</translation>
     </message>
     <message>
-        <location filename="window.py" line="111"/>
+        <location filename="../ReText/window.py" line="108"/>
         <source>Next tab</source>
         <translation>Следующая вкладка</translation>
     </message>
     <message>
-        <location filename="window.py" line="113"/>
+        <location filename="../ReText/window.py" line="110"/>
         <source>Previous tab</source>
         <translation>Предыдущая вкладка</translation>
     </message>
     <message>
-        <location filename="window.py" line="115"/>
+        <location filename="../ReText/window.py" line="112"/>
+        <source>Close tab</source>
+        <translation>Закрыть вкладку</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="114"/>
         <source>Print</source>
         <translation>Распечатать</translation>
     </message>
     <message>
-        <location filename="window.py" line="118"/>
+        <location filename="../ReText/window.py" line="117"/>
         <source>Print preview</source>
         <translation>Предпросмотр печати</translation>
     </message>
     <message>
-        <location filename="window.py" line="120"/>
+        <location filename="../ReText/window.py" line="119"/>
         <source>View HTML code</source>
         <translation>Просмотр кода HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="121"/>
+        <location filename="../ReText/window.py" line="120"/>
         <source>Change editor font</source>
         <translation>Изменить шрифт редактора</translation>
     </message>
     <message>
-        <location filename="window.py" line="123"/>
+        <location filename="../ReText/window.py" line="122"/>
         <source>Change preview font</source>
         <translation>Изменить шрифт просмотра</translation>
     </message>
     <message>
-        <location filename="window.py" line="125"/>
+        <location filename="../ReText/window.py" line="124"/>
         <source>Find text</source>
         <translation>Поиск текста</translation>
     </message>
     <message>
-        <location filename="window.py" line="129"/>
+        <location filename="../ReText/window.py" line="678"/>
+        <source>Go to line</source>
+        <translation>Перейти к строке</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="129"/>
         <source>Preview</source>
         <translation>Просмотр</translation>
     </message>
     <message>
-        <location filename="window.py" line="139"/>
+        <location filename="../ReText/window.py" line="139"/>
         <source>Live preview</source>
         <translation>Живой просмотр</translation>
     </message>
     <message>
-        <location filename="window.py" line="144"/>
+        <location filename="../ReText/window.py" line="144"/>
+        <source>Insert table</source>
+        <translation>Вставить таблицу</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="146"/>
         <source>Table editing mode</source>
         <translation>Режим редактирования таблиц</translation>
     </message>
     <message>
-        <location filename="window.py" line="148"/>
+        <location filename="../ReText/window.py" line="152"/>
         <source>FakeVim mode</source>
         <translation>Режим FakeVim</translation>
     </message>
     <message>
-        <location filename="window.py" line="153"/>
+        <location filename="../ReText/window.py" line="157"/>
         <source>Fullscreen mode</source>
         <translation>Полноэкранный режим</translation>
     </message>
     <message>
-        <location filename="window.py" line="588"/>
+        <location filename="../ReText/window.py" line="630"/>
         <source>Preferences</source>
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="window.py" line="163"/>
+        <location filename="../ReText/window.py" line="168"/>
         <source>Quit</source>
         <translation>Выход</translation>
     </message>
     <message>
-        <location filename="window.py" line="166"/>
+        <location filename="../ReText/window.py" line="171"/>
         <source>Undo</source>
         <translation>Отменить действие</translation>
     </message>
     <message>
-        <location filename="window.py" line="168"/>
+        <location filename="../ReText/window.py" line="173"/>
         <source>Redo</source>
         <translation>Повторить действие</translation>
     </message>
     <message>
-        <location filename="window.py" line="170"/>
+        <location filename="../ReText/window.py" line="175"/>
         <source>Copy</source>
         <translation>Копировать</translation>
     </message>
     <message>
-        <location filename="window.py" line="172"/>
+        <location filename="../ReText/window.py" line="177"/>
         <source>Cut</source>
         <translation>Вырезать</translation>
     </message>
     <message>
-        <location filename="window.py" line="174"/>
+        <location filename="../ReText/window.py" line="179"/>
         <source>Paste</source>
         <translation>Вставить</translation>
     </message>
     <message>
-        <location filename="window.py" line="184"/>
+        <location filename="../ReText/window.py" line="181"/>
+        <source>Paste image</source>
+        <translation>Вставить изображение</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="183"/>
+        <source>Move line up</source>
+        <translation>Переместить строку вверх</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="185"/>
+        <source>Move line down</source>
+        <translation>Переместить строку вниз</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="195"/>
         <source>Enable</source>
         <translation>Включить</translation>
     </message>
     <message>
-        <location filename="window.py" line="185"/>
+        <location filename="../ReText/window.py" line="196"/>
         <source>Set locale</source>
         <translation>Установить локаль</translation>
     </message>
     <message>
-        <location filename="window.py" line="186"/>
+        <location filename="../ReText/window.py" line="197"/>
         <source>Use WebKit renderer</source>
         <translation>Использовать движок WebKit</translation>
     </message>
     <message>
-        <location filename="window.py" line="191"/>
+        <location filename="../ReText/window.py" line="202"/>
         <source>Use WebEngine (Chromium) renderer</source>
         <translation>Использовать движок WebEngine (Chromium)</translation>
     </message>
     <message>
-        <location filename="window.py" line="196"/>
+        <location filename="../ReText/window.py" line="207"/>
         <source>Show directory</source>
         <translation>Открыть папку</translation>
     </message>
     <message>
-        <location filename="window.py" line="197"/>
+        <location filename="../ReText/window.py" line="208"/>
         <source>Next</source>
         <translation>Следующее</translation>
     </message>
     <message>
-        <location filename="window.py" line="199"/>
+        <location filename="../ReText/window.py" line="210"/>
         <source>Previous</source>
         <translation>Предыдущее</translation>
     </message>
     <message>
-        <location filename="window.py" line="201"/>
+        <location filename="../ReText/window.py" line="212"/>
         <source>Replace</source>
         <translation>Заменить</translation>
     </message>
     <message>
-        <location filename="window.py" line="203"/>
+        <location filename="../ReText/window.py" line="214"/>
         <source>Replace all</source>
         <translation>Заменить все</translation>
     </message>
     <message>
-        <location filename="window.py" line="207"/>
+        <location filename="../ReText/window.py" line="218"/>
         <source>Close</source>
         <translation>Закрыть</translation>
     </message>
     <message>
-        <location filename="window.py" line="210"/>
+        <location filename="../ReText/window.py" line="222"/>
         <source>Get help online</source>
         <translation>Получить помощь в интернете</translation>
     </message>
     <message>
-        <location filename="window.py" line="211"/>
+        <location filename="../ReText/window.py" line="223"/>
         <source>About ReText</source>
         <translation>О ReText</translation>
     </message>
     <message>
-        <location filename="window.py" line="214"/>
+        <location filename="../ReText/window.py" line="226"/>
         <source>About Qt</source>
         <translation>О Qt</translation>
     </message>
     <message>
-        <location filename="window.py" line="229"/>
+        <location filename="../ReText/window.py" line="241"/>
         <source>Bold</source>
         <translation>Полужирный</translation>
     </message>
     <message>
-        <location filename="window.py" line="231"/>
+        <location filename="../ReText/window.py" line="243"/>
         <source>Italic</source>
         <translation>Курсив</translation>
     </message>
     <message>
-        <location filename="window.py" line="233"/>
+        <location filename="../ReText/window.py" line="245"/>
         <source>Underline</source>
         <translation>Подчёркивание</translation>
     </message>
     <message>
-        <location filename="window.py" line="299"/>
+        <location filename="../ReText/window.py" line="318"/>
         <source>Formatting</source>
         <translation>Форматирование</translation>
     </message>
     <message>
-        <location filename="window.py" line="245"/>
+        <location filename="../ReText/window.py" line="258"/>
         <source>Symbols</source>
         <translation>Символы</translation>
     </message>
     <message>
-        <location filename="window.py" line="250"/>
+        <location filename="../ReText/window.py" line="263"/>
         <source>File</source>
         <translation>Файл</translation>
     </message>
     <message>
-        <location filename="window.py" line="251"/>
+        <location filename="../ReText/window.py" line="264"/>
         <source>Edit</source>
         <translation>Правка</translation>
     </message>
     <message>
-        <location filename="window.py" line="252"/>
+        <location filename="../ReText/window.py" line="265"/>
         <source>Help</source>
         <translation>Справка</translation>
     </message>
     <message>
-        <location filename="window.py" line="255"/>
+        <location filename="../ReText/window.py" line="268"/>
         <source>Open recent</source>
         <translation>Открыть последние</translation>
     </message>
     <message>
-        <location filename="window.py" line="267"/>
+        <location filename="../ReText/window.py" line="281"/>
         <source>Export</source>
         <translation>Экспорт</translation>
     </message>
     <message>
-        <location filename="window.py" line="288"/>
+        <location filename="../ReText/window.py" line="306"/>
         <source>Spell check</source>
         <translation>Проверка орфографии</translation>
     </message>
     <message>
-        <location filename="window.py" line="296"/>
+        <location filename="../ReText/window.py" line="315"/>
         <source>Default markup</source>
         <translation>Язык разметки по умолчанию</translation>
     </message>
     <message>
-        <location filename="window.py" line="339"/>
+        <location filename="../ReText/window.py" line="360"/>
         <source>Search</source>
         <translation>Поиск</translation>
     </message>
     <message>
-        <location filename="window.py" line="342"/>
+        <location filename="../ReText/window.py" line="363"/>
         <source>Replace with</source>
         <translation>Заменить на</translation>
     </message>
     <message>
-        <location filename="window.py" line="344"/>
+        <location filename="../ReText/window.py" line="365"/>
         <source>Case sensitively</source>
         <translation>Учитывать регистр</translation>
     </message>
     <message>
-        <location filename="window.py" line="492"/>
+        <location filename="../ReText/window.py" line="526"/>
         <source>New document</source>
         <translation>Новый документ</translation>
     </message>
     <message>
-        <location filename="window.py" line="664"/>
+        <location filename="../ReText/window.py" line="678"/>
+        <source>Type the line number</source>
+        <translation>Введите номер строки</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="714"/>
         <source>Please, save the file somewhere.</source>
         <translation>Сначала сохраните файл.</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="830"/>
         <source>Select one or several files to open</source>
         <translation>Выберите один или несколько файлов для открытия</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="1248"/>
         <source>Supported files</source>
         <translation>Поддерживаемые файлы</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="1248"/>
         <source>All files (*)</source>
         <translation>Все файлы (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="818"/>
+        <location filename="../ReText/window.py" line="869"/>
         <source>Select file encoding from the list:</source>
         <translation>Выберите кодировку файла из списка:</translation>
     </message>
     <message>
-        <location filename="window.py" line="839"/>
+        <location filename="../ReText/window.py" line="892"/>
         <source>Plain text (*.txt)</source>
         <translation>Простой текст (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="842"/>
+        <location filename="../ReText/window.py" line="895"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>Файлы %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="919"/>
+        <location filename="../ReText/window.py" line="970"/>
         <source>Save file</source>
         <translation>Сохранить файл</translation>
     </message>
     <message>
-        <location filename="window.py" line="860"/>
+        <location filename="../ReText/window.py" line="915"/>
         <source>Cannot save to file which is open in another tab!</source>
         <translation>Невозможно сохранить в файл, который открыт в другой вкладке!</translation>
     </message>
     <message>
-        <location filename="window.py" line="884"/>
+        <location filename="../ReText/window.py" line="938"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Невозможно сохранить в файл, так как он доступен только для чтения!</translation>
     </message>
     <message>
-        <location filename="window.py" line="909"/>
+        <location filename="../ReText/window.py" line="960"/>
         <source>Export document to ODT</source>
         <translation>Экспортировать документ как ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="909"/>
+        <location filename="../ReText/window.py" line="960"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Файлы текста OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="919"/>
+        <location filename="../ReText/window.py" line="970"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Файлы HTML (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="940"/>
+        <location filename="../ReText/window.py" line="993"/>
+        <source>Unrecognized paperSize setting &quot;%s&quot;.</source>
+        <translation>Неверное значение параметра paperSize: «%s»</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="1019"/>
         <source>Export document to PDF</source>
         <translation>Экспортировать документ как PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="940"/>
+        <location filename="../ReText/window.py" line="1019"/>
         <source>PDF files (*.pdf)</source>
         <translation>Файлы PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="960"/>
+        <location filename="../ReText/window.py" line="1046"/>
         <source>Print document</source>
         <translation>Распечатать документ</translation>
     </message>
     <message>
-        <location filename="window.py" line="984"/>
+        <location filename="../ReText/window.py" line="1069"/>
         <source>Export document</source>
         <translation>Экспортировать документ</translation>
     </message>
     <message>
-        <location filename="window.py" line="1005"/>
+        <location filename="../ReText/window.py" line="1090"/>
         <source>Failed to execute the command:</source>
         <translation>Невозможно запустить команду:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1039"/>
+        <location filename="../ReText/window.py" line="1131"/>
         <source>Alt text</source>
         <translation>Альтернативный текст</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="../ReText/window.py" line="1132"/>
         <source>URL</source>
         <translation>URL</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="../ReText/window.py" line="1132"/>
         <source>Link text</source>
         <translation>Текст ссылки</translation>
     </message>
     <message>
-        <location filename="window.py" line="1080"/>
+        <location filename="../ReText/window.py" line="1173"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
         <translation>Этот файл был удалён другим приложением.
 Пожалуйста, убедитесь перед выходом, что вы сохранили файл.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1087"/>
+        <location filename="../ReText/window.py" line="1181"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
@@ -573,51 +710,88 @@ Do you want to reload the file (this will discard all your changes)?
 </translation>
     </message>
     <message>
-        <location filename="window.py" line="1092"/>
+        <location filename="../ReText/window.py" line="1186"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
         <translation>Если вы решите не перезагружать файл, режим автоматического сохранения будет отключён для этого сеанса в целях предотвращения потери данных.</translation>
     </message>
     <message>
-        <location filename="window.py" line="1116"/>
+        <location filename="../ReText/window.py" line="1210"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Документ был изменён.
 Сохранить изменения?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1145"/>
+        <location filename="../ReText/window.py" line="1238"/>
         <source>HTML code</source>
         <translation>код HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>ReText %s (using PyMarkups %s)</source>
         <translation>ReText %s (использует PyMarkups %s)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Простой, но мощный редактор для Markdown и reStructuredText</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Автор: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Website</source>
         <translation>Веб-сайт</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Markdown syntax</source>
         <translation>Синтаксис Markdown</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>reStructuredText syntax</source>
         <translation>Синтаксис reStructuredText</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="149"/>
+        <source>Insert images by file path</source>
+        <translation>Вставить изображения из файлов</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="1248"/>
+        <source>Select one or several images to open</source>
+        <translation>Выберите одно или несколько изображений для вставки</translation>
+    </message>
+</context>
+<context>
+    <name>TextInfoArea</name>
+    <message>
+        <location filename="../ReText/editor.py" line="582"/>
+        <source>%d w | %d a | %d c</source>
+        <comment>count of words, alphanumeric characters, all characters</comment>
+        <translation>%d w | %d a | %d c</translation>
+    </message>
+</context>
+<context>
+    <name>main</name>
+    <message>
+        <location filename="../ReText/__main__.py" line="77"/>
+        <source>Open the files in preview mode</source>
+        <translation>Открывать файлы в режиме просмотра</translation>
+    </message>
+    <message>
+        <location filename="../ReText/__main__.py" line="79"/>
+        <source>Create a new window even if there is an existing one</source>
+        <translation>Создать новое окно, даже если есть существующее</translation>
+    </message>
+    <message>
+        <location filename="../ReText/__main__.py" line="83"/>
+        <source>List of files to open</source>
+        <translation>Перечислите файлы для открытия</translation>
+    </message>
 </context>
 </TS>
