@@ -3,118 +3,186 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="80"/>
+        <source>Using configuration file at:</source>
+        <translation>使用配置文件：</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Behavior</source>
         <translation>行为</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Automatically save documents</source>
         <translation>自动保存文件</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Automatically open last documents on startup</source>
+        <translation>启动时自动打开上一个文档</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Number of recent documents</source>
+        <translation>最近文件数</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Restore window geometry</source>
         <translation>恢复窗口位置大小</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
-        <source>Use live preview by default</source>
-        <translation>默认使用实时预览</translation>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Default preview state</source>
+        <translation>默认上次状态</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Open external links in ReText window</source>
         <translation>在 ReText 窗口中打开外部链接</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Markdown syntax extensions (comma-separated)</source>
         <translation>Markdown 语法扩展 (逗号分隔)</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Enable synchronized scrolling for Markdown</source>
         <translation>对Markdown开启编辑与预览的同步滚动</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="169"/>
         <source>Editor</source>
         <translation>编辑</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Highlight current line</source>
         <translation>高亮显示当前行</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Show line numbers</source>
         <translation>显示行号</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Line numbers are relative to current line</source>
+        <translation>行号与当前行相关</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Tab key inserts spaces</source>
         <translation>使用 空格 替换 Tab</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Tabulation width</source>
         <translation>Tab 键宽度</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Draw vertical line at column</source>
         <translation>画出垂直边界线</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Enable soft wrap</source>
+        <translation>启用软包装</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Show document stats</source>
+        <translation>显示文档统计信息</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Interface</source>
         <translation>交互界面</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Hide toolbar</source>
+        <translation>隐藏标题栏</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Icon theme name</source>
         <translation>图标主题名称</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
+        <location filename="../ReText/config.py" line="97"/>
         <source>Stylesheet file</source>
         <translation>样式表文件</translation>
     </message>
     <message>
-        <location filename="config.py" line="104"/>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Hide tabs bar when there is only one tab</source>
+        <translation>只有一个选项卡时隐藏选项卡栏</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="97"/>
+        <source>Show full path in window title</source>
+        <translation>窗口标题显示全部路径</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="151"/>
         <source>Help</source>
         <translation>帮助</translation>
     </message>
     <message>
-        <location filename="config.py" line="67"/>
-        <source>Automatically open last documents on startup</source>
-        <translation type="unfinished"></translation>
+        <location filename="../ReText/config.py" line="170"/>
+        <source>Live preview</source>
+        <translation>实时预览</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="171"/>
+        <source>Normal preview</source>
+        <translation>正常预览</translation>
     </message>
 </context>
 <context>
     <name>FileSelectButton</name>
     <message>
-        <location filename="config.py" line="34"/>
+        <location filename="../ReText/config.py" line="35"/>
         <source>(none)</source>
         <translation>（无）</translation>
     </message>
     <message>
-        <location filename="config.py" line="41"/>
+        <location filename="../ReText/config.py" line="42"/>
         <source>Select file to open</source>
         <translation>打开文件</translation>
     </message>
 </context>
+<context>
+    <name>InsertTableDialog</name>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="27"/>
+        <source>Insert table</source>
+        <translation>插入表格</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="36"/>
+        <source>Number of rows</source>
+        <translation>行数</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tabledialog.py" line="37"/>
+        <source>Number of columns</source>
+        <translation>列数</translation>
+    </message>
+</context>
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="dialogs.py" line="44"/>
+        <location filename="../ReText/dialogs.py" line="44"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>输入语言名称 (例如: zh_CN)</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="50"/>
+        <location filename="../ReText/dialogs.py" line="50"/>
         <source>Set as default</source>
         <translation>设为默认</translation>
     </message>
@@ -122,12 +190,12 @@
 <context>
     <name>Proxy</name>
     <message>
-        <location filename="fakevimeditor.py" line="64"/>
+        <location filename="../ReText/fakevimeditor.py" line="61"/>
         <source>No write since last change (add ! to override)</source>
         <translation>已修改但尚未保存（可用 ! 强制执行）</translation>
     </message>
     <message>
-        <location filename="fakevimeditor.py" line="121"/>
+        <location filename="../ReText/fakevimeditor.py" line="118"/>
         <source>Information</source>
         <translation>信息</translation>
     </message>
@@ -135,12 +203,17 @@
 <context>
     <name>ReTextEdit</name>
     <message>
-        <location filename="editor.py" line="292"/>
+        <location filename="../ReText/editor.py" line="212"/>
+        <source>Add to dictionary</source>
+        <translation>添加到词典</translation>
+    </message>
+    <message>
+        <location filename="../ReText/editor.py" line="391"/>
         <source>Save image</source>
         <translation>保存图片</translation>
     </message>
     <message>
-        <location filename="editor.py" line="292"/>
+        <location filename="../ReText/editor.py" line="391"/>
         <source>Images (*.png *.jpg)</source>
         <translation>图片 (*.png *.jpg)</translation>
     </message>
@@ -148,474 +221,574 @@
 <context>
     <name>ReTextTab</name>
     <message>
-        <location filename="tab.py" line="183"/>
+        <location filename="../ReText/tab.py" line="184"/>
         <source>New document</source>
         <translation>新建文档</translation>
     </message>
     <message>
-        <location filename="tab.py" line="188"/>
+        <location filename="../ReText/tab.py" line="189"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation>不能粘贴文件内容，检查下是否安装了 &lt;a href=&quot;%s&quot;&gt;必要模块&lt;/a&gt; ！</translation>
     </message>
+    <message>
+        <location filename="../ReText/tab.py" line="478"/>
+        <source>Create missing file?</source>
+        <translation>创建丢失文件？</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="478"/>
+        <source>The file &apos;%s&apos; does not exist.
+
+Do you want to create it?</source>
+        <translation>&apos;%s&apos; 不存在。
+是否创建？</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="511"/>
+        <source>File could not be created</source>
+        <translation>无法创建文件</translation>
+    </message>
+    <message>
+        <location filename="../ReText/tab.py" line="511"/>
+        <source>Could not create file &apos;%s&apos;: %s</source>
+        <translation>无法创建文件 &apos;%s&apos;: %s</translation>
+    </message>
 </context>
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="85"/>
+        <location filename="../ReText/window.py" line="82"/>
         <source>File toolbar</source>
         <translation>文件工具栏</translation>
     </message>
     <message>
-        <location filename="window.py" line="87"/>
+        <location filename="../ReText/window.py" line="84"/>
         <source>Edit toolbar</source>
         <translation>编辑工具栏</translation>
     </message>
     <message>
-        <location filename="window.py" line="89"/>
+        <location filename="../ReText/window.py" line="86"/>
         <source>Search toolbar</source>
         <translation>搜索工具栏</translation>
     </message>
     <message>
-        <location filename="window.py" line="93"/>
+        <location filename="../ReText/window.py" line="90"/>
         <source>New</source>
         <translation>新建</translation>
     </message>
     <message>
-        <location filename="window.py" line="96"/>
+        <location filename="../ReText/window.py" line="93"/>
         <source>Open</source>
         <translation>打开</translation>
     </message>
     <message>
-        <location filename="window.py" line="99"/>
+        <location filename="../ReText/window.py" line="96"/>
         <source>Set encoding</source>
-        <translation>设置编码方式</translation>
+        <translation>设置文本编码格式</translation>
     </message>
     <message>
-        <location filename="window.py" line="1096"/>
+        <location filename="../ReText/window.py" line="1190"/>
         <source>Reload</source>
-        <translation>重载</translation>
+        <translation>重新加载</translation>
     </message>
     <message>
-        <location filename="window.py" line="105"/>
+        <location filename="../ReText/window.py" line="102"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
     <message>
-        <location filename="window.py" line="109"/>
+        <location filename="../ReText/window.py" line="106"/>
         <source>Save as</source>
         <translation>另存为</translation>
     </message>
     <message>
-        <location filename="window.py" line="111"/>
+        <location filename="../ReText/window.py" line="108"/>
         <source>Next tab</source>
         <translation>下一个标签</translation>
     </message>
     <message>
-        <location filename="window.py" line="113"/>
+        <location filename="../ReText/window.py" line="110"/>
         <source>Previous tab</source>
         <translation>上一个标签</translation>
     </message>
     <message>
-        <location filename="window.py" line="115"/>
+        <location filename="../ReText/window.py" line="112"/>
+        <source>Close tab</source>
+        <translation>关闭标签</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="114"/>
         <source>Print</source>
         <translation>打印</translation>
     </message>
     <message>
-        <location filename="window.py" line="118"/>
+        <location filename="../ReText/window.py" line="117"/>
         <source>Print preview</source>
         <translation>打印预览</translation>
     </message>
     <message>
-        <location filename="window.py" line="120"/>
+        <location filename="../ReText/window.py" line="119"/>
         <source>View HTML code</source>
         <translation>查看 HTML 代码</translation>
     </message>
     <message>
-        <location filename="window.py" line="121"/>
+        <location filename="../ReText/window.py" line="120"/>
         <source>Change editor font</source>
         <translation>修改编辑器字体</translation>
     </message>
     <message>
-        <location filename="window.py" line="123"/>
+        <location filename="../ReText/window.py" line="122"/>
         <source>Change preview font</source>
         <translation>修改预览字体</translation>
     </message>
     <message>
-        <location filename="window.py" line="125"/>
+        <location filename="../ReText/window.py" line="124"/>
         <source>Find text</source>
         <translation>查找文本</translation>
     </message>
     <message>
-        <location filename="window.py" line="129"/>
+        <location filename="../ReText/window.py" line="678"/>
+        <source>Go to line</source>
+        <translation>到行处</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="129"/>
         <source>Preview</source>
         <translation>预览</translation>
     </message>
     <message>
-        <location filename="window.py" line="139"/>
+        <location filename="../ReText/window.py" line="139"/>
         <source>Live preview</source>
         <translation>实时预览</translation>
     </message>
     <message>
-        <location filename="window.py" line="148"/>
+        <location filename="../ReText/window.py" line="144"/>
+        <source>Insert table</source>
+        <translation>插入表格</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="146"/>
+        <source>Table editing mode</source>
+        <translation>表格编辑模式</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="152"/>
         <source>FakeVim mode</source>
         <translation>FakeVim 模式</translation>
     </message>
     <message>
-        <location filename="window.py" line="153"/>
+        <location filename="../ReText/window.py" line="157"/>
         <source>Fullscreen mode</source>
         <translation>全屏模式</translation>
     </message>
     <message>
-        <location filename="window.py" line="588"/>
+        <location filename="../ReText/window.py" line="630"/>
         <source>Preferences</source>
-        <translation>个人偏好</translation>
+        <translation>个人偏好设定</translation>
     </message>
     <message>
-        <location filename="window.py" line="163"/>
+        <location filename="../ReText/window.py" line="168"/>
         <source>Quit</source>
         <translation>退出</translation>
     </message>
     <message>
-        <location filename="window.py" line="166"/>
+        <location filename="../ReText/window.py" line="171"/>
         <source>Undo</source>
         <translation>取消</translation>
     </message>
     <message>
-        <location filename="window.py" line="168"/>
+        <location filename="../ReText/window.py" line="173"/>
         <source>Redo</source>
         <translation>重做</translation>
     </message>
     <message>
-        <location filename="window.py" line="170"/>
+        <location filename="../ReText/window.py" line="175"/>
         <source>Copy</source>
         <translation>复制</translation>
     </message>
     <message>
-        <location filename="window.py" line="172"/>
+        <location filename="../ReText/window.py" line="177"/>
         <source>Cut</source>
         <translation>剪切</translation>
     </message>
     <message>
-        <location filename="window.py" line="174"/>
+        <location filename="../ReText/window.py" line="179"/>
         <source>Paste</source>
         <translation>粘贴</translation>
     </message>
     <message>
-        <location filename="window.py" line="184"/>
+        <location filename="../ReText/window.py" line="181"/>
+        <source>Paste image</source>
+        <translation>粘贴图片</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="183"/>
+        <source>Move line up</source>
+        <translation>上移</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="185"/>
+        <source>Move line down</source>
+        <translation>下移</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="195"/>
         <source>Enable</source>
         <translation>激活</translation>
     </message>
     <message>
-        <location filename="window.py" line="185"/>
+        <location filename="../ReText/window.py" line="196"/>
         <source>Set locale</source>
         <translation>选择界面语言</translation>
     </message>
     <message>
-        <location filename="window.py" line="186"/>
+        <location filename="../ReText/window.py" line="197"/>
         <source>Use WebKit renderer</source>
         <translation>使用 WebKit 渲染</translation>
     </message>
     <message>
-        <location filename="window.py" line="196"/>
+        <location filename="../ReText/window.py" line="202"/>
+        <source>Use WebEngine (Chromium) renderer</source>
+        <translation>使用 WebEngine (Chromium)  渲染器</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="207"/>
         <source>Show directory</source>
         <translation>显示文件夹</translation>
     </message>
     <message>
-        <location filename="window.py" line="197"/>
+        <location filename="../ReText/window.py" line="208"/>
         <source>Next</source>
         <translation>下一项</translation>
     </message>
     <message>
-        <location filename="window.py" line="199"/>
+        <location filename="../ReText/window.py" line="210"/>
         <source>Previous</source>
         <translation>上一项</translation>
     </message>
     <message>
-        <location filename="window.py" line="207"/>
+        <location filename="../ReText/window.py" line="212"/>
+        <source>Replace</source>
+        <translation>替换</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="214"/>
+        <source>Replace all</source>
+        <translation>替换所有</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="218"/>
         <source>Close</source>
         <translation>关闭</translation>
     </message>
     <message>
-        <location filename="window.py" line="210"/>
+        <location filename="../ReText/window.py" line="222"/>
         <source>Get help online</source>
         <translation>在线获取帮助（英文）</translation>
     </message>
     <message>
-        <location filename="window.py" line="211"/>
+        <location filename="../ReText/window.py" line="223"/>
         <source>About ReText</source>
         <translation>关于 ReText</translation>
     </message>
     <message>
-        <location filename="window.py" line="214"/>
+        <location filename="../ReText/window.py" line="226"/>
         <source>About Qt</source>
         <translation>关于 Qt</translation>
     </message>
     <message>
-        <location filename="window.py" line="229"/>
+        <location filename="../ReText/window.py" line="241"/>
         <source>Bold</source>
-        <translation>加粗</translation>
+        <translation>粗体</translation>
     </message>
     <message>
-        <location filename="window.py" line="231"/>
+        <location filename="../ReText/window.py" line="243"/>
         <source>Italic</source>
-        <translation>倾斜</translation>
+        <translation>斜体</translation>
     </message>
     <message>
-        <location filename="window.py" line="233"/>
+        <location filename="../ReText/window.py" line="245"/>
         <source>Underline</source>
         <translation>下划线</translation>
     </message>
     <message>
-        <location filename="window.py" line="299"/>
+        <location filename="../ReText/window.py" line="318"/>
         <source>Formatting</source>
         <translation>字符样式</translation>
     </message>
     <message>
-        <location filename="window.py" line="245"/>
+        <location filename="../ReText/window.py" line="258"/>
         <source>Symbols</source>
         <translation>符号</translation>
     </message>
     <message>
-        <location filename="window.py" line="250"/>
+        <location filename="../ReText/window.py" line="263"/>
         <source>File</source>
         <translation>文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="251"/>
+        <location filename="../ReText/window.py" line="264"/>
         <source>Edit</source>
         <translation>编辑</translation>
     </message>
     <message>
-        <location filename="window.py" line="252"/>
+        <location filename="../ReText/window.py" line="265"/>
         <source>Help</source>
         <translation>帮助</translation>
     </message>
     <message>
-        <location filename="window.py" line="255"/>
+        <location filename="../ReText/window.py" line="268"/>
         <source>Open recent</source>
         <translation>打开最近使用</translation>
     </message>
     <message>
-        <location filename="window.py" line="267"/>
+        <location filename="../ReText/window.py" line="281"/>
         <source>Export</source>
         <translation>导出</translation>
     </message>
     <message>
-        <location filename="window.py" line="288"/>
+        <location filename="../ReText/window.py" line="306"/>
         <source>Spell check</source>
         <translation>拼写检查</translation>
     </message>
     <message>
-        <location filename="window.py" line="296"/>
+        <location filename="../ReText/window.py" line="315"/>
         <source>Default markup</source>
         <translation>默认编辑模式</translation>
     </message>
     <message>
-        <location filename="window.py" line="339"/>
+        <location filename="../ReText/window.py" line="360"/>
         <source>Search</source>
         <translation>搜索</translation>
     </message>
     <message>
-        <location filename="window.py" line="344"/>
+        <location filename="../ReText/window.py" line="363"/>
+        <source>Replace with</source>
+        <translation>替换为</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="365"/>
         <source>Case sensitively</source>
         <translation>对大小写敏感</translation>
     </message>
     <message>
-        <location filename="window.py" line="492"/>
+        <location filename="../ReText/window.py" line="526"/>
         <source>New document</source>
         <translation>新文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="664"/>
-        <source>Please, save the file somewhere.</source>
-        <translation>请，保存到别的地方呦！</translation>
+        <location filename="../ReText/window.py" line="678"/>
+        <source>Type the line number</source>
+        <translation>输入数字</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="714"/>
+        <source>Please, save the file somewhere.</source>
+        <translation>请保存到别处！</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="830"/>
         <source>Select one or several files to open</source>
         <translation>选择一个或多个文件打开</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="1248"/>
         <source>Supported files</source>
         <translation>支持的文件类型</translation>
     </message>
     <message>
-        <location filename="window.py" line="780"/>
+        <location filename="../ReText/window.py" line="1248"/>
         <source>All files (*)</source>
         <translation>全部文件 (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="818"/>
+        <location filename="../ReText/window.py" line="869"/>
         <source>Select file encoding from the list:</source>
         <translation>从列表中选择文件编码方式</translation>
     </message>
     <message>
-        <location filename="window.py" line="839"/>
+        <location filename="../ReText/window.py" line="892"/>
         <source>Plain text (*.txt)</source>
         <translation>普通文本文档 (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="842"/>
+        <location filename="../ReText/window.py" line="895"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>%s 文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="919"/>
+        <location filename="../ReText/window.py" line="970"/>
         <source>Save file</source>
         <translation>保存文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="884"/>
+        <location filename="../ReText/window.py" line="915"/>
+        <source>Cannot save to file which is open in another tab!</source>
+        <translation>已在其它标签处打开，当前无法保存。</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="938"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>不能保存文件因为当前文件或文件夹只读！</translation>
     </message>
     <message>
-        <location filename="window.py" line="909"/>
+        <location filename="../ReText/window.py" line="960"/>
         <source>Export document to ODT</source>
-        <translation>导出文件到 ODT</translation>
+        <translation>导出为 ODT 文档</translation>
     </message>
     <message>
-        <location filename="window.py" line="909"/>
+        <location filename="../ReText/window.py" line="960"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>OpenDocument 文本文件 (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="919"/>
+        <location filename="../ReText/window.py" line="970"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>HTML 文件 (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="940"/>
-        <source>Export document to PDF</source>
-        <translation>导出文件到 PDF</translation>
+        <location filename="../ReText/window.py" line="993"/>
+        <source>Unrecognized paperSize setting &quot;%s&quot;.</source>
+        <translation>无法识别的纸张大小设置 &quot;%s&quot;</translation>
     </message>
     <message>
-        <location filename="window.py" line="940"/>
+        <location filename="../ReText/window.py" line="1019"/>
+        <source>Export document to PDF</source>
+        <translation>导出格式为 PDF</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="1019"/>
         <source>PDF files (*.pdf)</source>
         <translation>PDF 文件 (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="960"/>
+        <location filename="../ReText/window.py" line="1046"/>
         <source>Print document</source>
         <translation>打印文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="984"/>
+        <location filename="../ReText/window.py" line="1069"/>
         <source>Export document</source>
         <translation>导出文件</translation>
     </message>
     <message>
-        <location filename="window.py" line="1005"/>
+        <location filename="../ReText/window.py" line="1090"/>
         <source>Failed to execute the command:</source>
         <translation>不能执行命令:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1039"/>
+        <location filename="../ReText/window.py" line="1131"/>
         <source>Alt text</source>
         <translation>替换文本</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="../ReText/window.py" line="1132"/>
         <source>URL</source>
-        <translation>URL</translation>
+        <translation>链接</translation>
     </message>
     <message>
-        <location filename="window.py" line="1040"/>
+        <location filename="../ReText/window.py" line="1132"/>
         <source>Link text</source>
         <translation>链接文本</translation>
     </message>
     <message>
-        <location filename="window.py" line="1080"/>
+        <location filename="../ReText/window.py" line="1173"/>
         <source>This file has been deleted by other application.
 Please make sure you save the file before exit.</source>
-        <translation>此文件已被其他应用程序删除。
-请确保在退出程序前保存了文件。</translation>
+        <translation>该文件已被其它程序删除。
+请确认在退出前保存。</translation>
     </message>
     <message>
-        <location filename="window.py" line="1087"/>
+        <location filename="../ReText/window.py" line="1181"/>
         <source>This document has been modified by other application.
 Do you want to reload the file (this will discard all your changes)?
 </source>
-        <translation>文件已被其他程序修改。
-要重新载入文件（丢弃所有修改）吗？
+        <translation>文件已被其它程序修改。
+要重新载入文件（放弃当前所有修改）吗？
 </translation>
     </message>
     <message>
-        <location filename="window.py" line="1092"/>
+        <location filename="../ReText/window.py" line="1186"/>
         <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
-        <translation>如果不重新载入文件，将禁用该会话的自动保存模式，以防止数据丢失。</translation>
+        <translation>如果不重新载入文件，为防止数据丢失，将禁用该会话的自动保存模式。</translation>
     </message>
     <message>
-        <location filename="window.py" line="1116"/>
+        <location filename="../ReText/window.py" line="1210"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>文件已更改，确认保存吗？</translation>
     </message>
     <message>
-        <location filename="window.py" line="1145"/>
+        <location filename="../ReText/window.py" line="1238"/>
         <source>HTML code</source>
         <translation>HTML 代码</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>ReText %s (using PyMarkups %s)</source>
         <translation>ReText %s（使用 PyMarkups %s）</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>简单高效的 Markdown 与 ReStructuredText 编辑器</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>作者: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Website</source>
         <translation>网站</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>Markdown syntax</source>
         <translation>Markdown 语法</translation>
     </message>
     <message>
-        <location filename="window.py" line="1156"/>
+        <location filename="../ReText/window.py" line="1266"/>
         <source>reStructuredText syntax</source>
         <translation>reStructuredText 语法</translation>
     </message>
     <message>
-        <location filename="window.py" line="144"/>
-        <source>Table editing mode</source>
+        <location filename="../ReText/window.py" line="149"/>
+        <source>Insert images by file path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="201"/>
-        <source>Replace</source>
+        <location filename="../ReText/window.py" line="1248"/>
+        <source>Select one or several images to open</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>TextInfoArea</name>
+    <message>
+        <location filename="../ReText/editor.py" line="582"/>
+        <source>%d w | %d a | %d c</source>
+        <comment>count of words, alphanumeric characters, all characters</comment>
+        <translation>%d w | %d a | %d c</translation>
+    </message>
+</context>
+<context>
+    <name>main</name>
+    <message>
+        <location filename="../ReText/__main__.py" line="77"/>
+        <source>Open the files in preview mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="203"/>
-        <source>Replace all</source>
+        <location filename="../ReText/__main__.py" line="79"/>
+        <source>Create a new window even if there is an existing one</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="342"/>
-        <source>Replace with</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="860"/>
-        <source>Cannot save to file which is open in another tab!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="window.py" line="191"/>
-        <source>Use WebEngine (Chromium) renderer</source>
+        <location filename="../ReText/__main__.py" line="83"/>
+        <source>List of files to open</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
