@@ -27,8 +27,7 @@ from PyQt5.QtCore import Qt, QMimeData
 from PyQt5.QtWidgets import QApplication
 from markups import MarkdownMarkup, ReStructuredTextMarkup
 
-if hasattr(Qt, 'AA_ShareOpenGLContexts'):
-	QApplication.setAttribute(Qt.AA_ShareOpenGLContexts)
+QApplication.setAttribute(Qt.AA_ShareOpenGLContexts)
 # Keep a reference so it is not garbage collected
 app = QApplication.instance() or QApplication(sys.argv)
 
@@ -106,40 +105,34 @@ class TestClipboardHandling(unittest.TestCase):
 		image.fill(Qt.green)
 		return image
 
-	def test_allowTextOnClipboard(self):
-		mimeData = QMimeData()
-		mimeData.setText('hello')
-		self.assertTrue(self.editor.canInsertFromMimeData(mimeData))
-
-	def test_allowImageOnClipboard(self):
-		mimeData = QMimeData()
-		mimeData.setImageData(self._create_image())
-		self.assertTrue(self.editor.canInsertFromMimeData(mimeData))
-
 	def test_pasteText(self):
 		mimeData = QMimeData()
 		mimeData.setText('pasted text')
 		self.editor.insertFromMimeData(mimeData)
 		self.assertTrue('pasted text' in self.editor.toPlainText())
 
-	@patch.object(ReTextEdit, 'getImageFilenameAndLink', return_value=('/tmp/myimage.jpg', 'myimage.jpg'))
+	@patch.object(ReTextEdit, 'getImageFilename', return_value='/tmp/myimage.jpg')
 	@patch.object(QImage, 'save')
 	def test_pasteImage_Markdown(self, _mock_image, _mock_editor):
 		mimeData = QMimeData()
 		mimeData.setImageData(self._create_image())
+		app.clipboard().setMimeData(mimeData)
 		self.dummytab.markupClass = MarkdownMarkup
+		self.dummytab.fileName = '/tmp/foo.md'
 
-		self.editor.insertFromMimeData(mimeData)
+		self.editor.pasteImage()
 		self.assertTrue('![myimage](myimage.jpg)' in self.editor.toPlainText())
 
-	@patch.object(ReTextEdit, 'getImageFilenameAndLink', return_value=('/tmp/myimage.jpg', 'myimage.jpg'))
+	@patch.object(ReTextEdit, 'getImageFilename', return_value='/tmp/myimage.jpg')
 	@patch.object(QImage, 'save')
 	def test_pasteImage_RestructuredText(self, _mock_image, _mock_editor):
 		mimeData = QMimeData()
 		mimeData.setImageData(self._create_image())
+		app.clipboard().setMimeData(mimeData)
 		self.dummytab.markupClass = ReStructuredTextMarkup
+		self.dummytab.fileName = '/tmp/foo.rst'
 
-		self.editor.insertFromMimeData(mimeData)
+		self.editor.pasteImage()
 		self.assertTrue('.. image:: myimage.jpg' in self.editor.toPlainText())
 
 if __name__ == '__main__':
